@@ -1,26 +1,28 @@
+/*****************************************************************************
+ *   Copyright 2003 - 2010 Craig Drummond <craig.p.drummond@gmail.com>       *
+ *   Copyright 2013 - 2014 Yichao Yu <yyc1992@gmail.com>                     *
+ *                                                                           *
+ *   This program is free software; you can redistribute it and/or modify    *
+ *   it under the terms of the GNU Lesser General Public License as          *
+ *   published by the Free Software Foundation; either version 2.1 of the    *
+ *   License, or (at your option) version 3, or any later version accepted   *
+ *   by the membership of KDE e.V. (or its successor approved by the         *
+ *   membership of KDE e.V.), which shall act as a proxy defined in          *
+ *   Section 6 of version 3 of the license.                                  *
+ *                                                                           *
+ *   This program is distributed in the hope that it will be useful,         *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of          *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       *
+ *   Lesser General Public License for more details.                         *
+ *                                                                           *
+ *   You should have received a copy of the GNU Lesser General Public        *
+ *   License along with this library. If not,                                *
+ *   see <http://www.gnu.org/licenses/>.                                     *
+ *****************************************************************************/
+
 #ifndef __COMMON_H__
 #define __COMMON_H__
 
-/*
-  QtCurve (C) Craig Drummond, 2003 - 2010 craig.p.drummond@gmail.com
-
-  ----
-
-  This program is free software; you can redistr ibute it and/or
-  modify it under the terms of the GNU General Public
-  License version 2 as published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; see the file COPYING.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
-*/
-
 #include "config.h"
 #include <qtcurve-utils/shade.h>
 #include <qtcurve-utils/options.h>
@@ -42,8 +44,7 @@
 
 #include <gtk/gtk.h>
 #include <gdk/gdk.h>
-typedef GdkColor color;
-typedef gchar ** Strings;
+typedef char **Strings;
 
 #define SETTINGS_GROUP        "Settings"
 #define KWIN_GROUP            "KWin"
@@ -77,7 +78,6 @@ enum {
 #define SHADE_4_HIGHLIGHT (QTC_NUM_STD_SHADES + 1)
 #define SHADE_2_HIGHLIGHT (QTC_NUM_STD_SHADES + 2)
 
-#define SIMPLE_SHADING (!shading)
 #define DEFAULT_CONTRAST 7
 
 #define THIN_SBAR_MOD  ((opts.sliderWidth<DEFAULT_SLIDER_WIDTH ? 3 : opts.sliderWidth>DEFAULT_SLIDER_WIDTH ? (opts.sliderWidth-9)/2 : 4)+(EFFECT_NONE==opts.buttonEffect ? 1 : 0))
@@ -90,9 +90,6 @@ enum {
 #define ENTRY_INNER_ALPHA 0.4
 #define INACTIVE_SEL_ALPHA 0.5
 
-#define SUNKEN_BEVEL_DARK_ALPHA(X)  (X.value()/800.0) // 0.25
-#define SUNKEN_BEVEL_LIGHT_ALPHA(X) (X.value()/500.0) // 0.40
-
 #define BLEND_TITLEBAR     (opts.menubarAppearance==opts.titlebarAppearance && opts.menubarAppearance==opts.inactiveTitlebarAppearance && \
                            !(opts.windowBorder&WINDOW_BORDER_BLEND_TITLEBAR) && SHADE_WINDOW_BORDER==opts.shadeMenubars && opts.windowDrag)
 
@@ -105,25 +102,18 @@ enum {
 
 #define FRAME_DARK_SHADOW 2
 #define FOCUS_SHADE(SEL)         (FOCUS_GLOW==opts.focus ? GLOW_MO : ((SEL) ? 3 : ORIGINAL_SHADE))
-#define MENU_STRIPE_SHADE (USE_LIGHTER_POPUP_MENU ? ORIGINAL_SHADE : 2)
-#define MENU_SEP_SHADE    (USE_LIGHTER_POPUP_MENU ? 4 : 3)
+#define MENU_STRIPE_SHADE (opts.lighterPopupMenuBgnd ? ORIGINAL_SHADE : 2)
+#define MENU_SEP_SHADE    (opts.lighterPopupMenuBgnd ? 4 : 3)
 
 #define BGND_STRIPE_SHADE 0.95
 
-#define TAB_APPEARANCE(A) (A) /* (APPEARANCE_GLASS==(A) ? APPEARANCE_GRADIENT : (A)) */
-
 #define INVERT_SHADE(A) (1.0+(1.0-(A)))
 
-#define ROUNDED (ROUND_NONE!=opts.round)
-
 #define TOOLBAR_SEP_GAP        (opts.fadeLines ? 5 : 6)
 #define FADE_SIZE              0.4
-#define ETCHED_DARK            0.95
 
-#define IS_GLASS(A) (APPEARANCE_DULL_GLASS==(A) || APPEARANCE_SHINY_GLASS==(A))
+#define IS_GLASS(A) qtcOneOf(A, APPEARANCE_DULL_GLASS, APPEARANCE_SHINY_GLASS)
 #define IS_CUSTOM(A) ((A)>=APPEARANCE_CUSTOM1 && (A)<(APPEARANCE_CUSTOM1+NUM_CUSTOM_GRAD))
-#define IS_FLAT(A)  (APPEARANCE_FLAT==(A) || APPEARANCE_RAISED==(A) || APPEARANCE_FADE==(A))
-#define IS_FLAT_BGND(A)  (APPEARANCE_FLAT==(A) || APPEARANCE_RAISED==(A))
 
 #define MENUBAR_DARK_LIMIT (160<<8)
 #define TOO_DARK(A) ((A).red<MENUBAR_DARK_LIMIT || (A).green<MENUBAR_DARK_LIMIT || (A).blue<MENUBAR_DARK_LIMIT)
@@ -136,7 +126,6 @@ enum {
 #define MAX_HIGHLIGHT_FACTOR                      50
 #define MIN_HIGHLIGHT_FACTOR                     -50
 #define MENUBAR_DARK_FACTOR        TO_FACTOR(-3)
-#define INACTIVE_HIGHLIGHT_FACTOR  TO_FACTOR(20)
 #define LV_HEADER_DARK_FACTOR      TO_FACTOR(-10)
 #define DEF_POPUPMENU_LIGHT_FACTOR                 2
 #define MIN_LIGHTER_POPUP_MENU                  -100
@@ -146,7 +135,7 @@ enum {
 #define MAX_GB_FACTOR  50
 #define DEF_GB_FACTOR  -3
 
-#define TO_ALPHA(A) (((double)((A)<0 ? -(A) : (A)))/100.0)
+#define TO_ALPHA(A) (qtcAbs(A) / 100.0)
 #define DEF_COLOR_SEL_TAB_FACTOR  25
 #define MIN_COLOR_SEL_TAB_FACTOR   0
 #define MAX_COLOR_SEL_TAB_FACTOR 100
@@ -167,34 +156,26 @@ enum {
 
 #define SIZE_GRIP_SIZE 12
 
-#define USE_LIGHTER_POPUP_MENU (opts.lighterPopupMenuBgnd)
-#define USE_BORDER(B)          (GB_SHINE!=(B) && GB_NONE!=(B))
-#define DRAW_MENU_BORDER       (APPEARANCE_FLAT!=opts.menuBgndAppearance && opts.version>=qtcMakeVersion(1, 7) && \
-                                USE_BORDER(qtcGetGradient(opts.menuBgndAppearance, &opts)->border))
-
 #define USE_GLOW_FOCUS(mouseOver) (FOCUS_GLOW==opts.focus && (MO_GLOW!=opts.coloredMouseOver || !(mouseOver)))
 
-#define USE_SHADED_MENU_BAR_COLORS (SHADE_CUSTOM==opts.shadeMenubars || SHADE_BLEND_SELECTED==opts.shadeMenubars)
 #define MENUBAR_GLASS_SELECTED_DARK_FACTOR 0.9
-
 #define MENUITEM_FADE_SIZE 48
 
 #define NUM_SPLITTER_DASHES 21
 
-#define WIDGET_BUTTON(w) (WIDGET_STD_BUTTON==(w) || WIDGET_DEF_BUTTON==(w) || WIDGET_TOGGLE_BUTTON==(w) || \
-                          WIDGET_CHECKBOX==(w) || WIDGET_RADIO_BUTTON==(w) || \
-                          WIDGET_RADIO_BUTTON==(w) || WIDGET_COMBO==(w) || WIDGET_COMBO_BUTTON==(w) || WIDGET_UNCOLOURED_MO_BUTTON==(w) || \
-                          WIDGET_TOOLBAR_BUTTON==(w))
-#define ETCH_WIDGET(w) (WIDGET_STD_BUTTON==(w) || WIDGET_DEF_BUTTON==(w) || WIDGET_TOGGLE_BUTTON==(w) || WIDGET_SLIDER_TROUGH==(w) || \
-                        WIDGET_CHECKBOX==(w) || WIDGET_RADIO_BUTTON==(w) || \
-                        (WIDGET_SLIDER==(w) && MO_GLOW==opts.coloredMouseOver) || \
-                        WIDGET_FILLED_SLIDER_TROUGH==(w) || WIDGET_COMBO==(w) || WIDGET_UNCOLOURED_MO_BUTTON==(w) || \
-                        WIDGET_TOOLBAR_BUTTON==(w))
-#define AGUA_WIDGET(w) (WIDGET_STD_BUTTON==(w) || WIDGET_DEF_BUTTON==(w) || WIDGET_TOGGLE_BUTTON==(w) || IS_SLIDER((w)) || \
-                        WIDGET_CHECKBOX==(w) || WIDGET_RADIO_BUTTON==(w) || \
-                        WIDGET_COMBO==(w) WIDGET_COMBO_BUTTON==(w))
+#define WIDGET_BUTTON(w)                                                \
+    qtcOneOf(w, WIDGET_STD_BUTTON, WIDGET_DEF_BUTTON, WIDGET_TOGGLE_BUTTON, \
+             WIDGET_CHECKBOX, WIDGET_RADIO_BUTTON, WIDGET_RADIO_BUTTON, \
+             WIDGET_COMBO, WIDGET_COMBO_BUTTON, WIDGET_UNCOLOURED_MO_BUTTON, \
+             WIDGET_TOOLBAR_BUTTON)
+#define ETCH_WIDGET(w)                                                  \
+    (qtcOneOf(w, WIDGET_STD_BUTTON, WIDGET_DEF_BUTTON, WIDGET_TOGGLE_BUTTON, \
+              WIDGET_SLIDER_TROUGH, WIDGET_CHECKBOX, WIDGET_RADIO_BUTTON, \
+              WIDGET_FILLED_SLIDER_TROUGH, WIDGET_COMBO,                \
+              WIDGET_TOOLBAR_BUTTON, WIDGET_UNCOLOURED_MO_BUTTON) ||    \
+     ((w) == WIDGET_SLIDER && opts.coloredMouseOver == MO_GLOW))
 
-#define SLIDER(w) (WIDGET_SB_SLIDER==(w) || WIDGET_SLIDER==(w))
+#define SLIDER(w) qtcOneOf(w, WIDGET_SB_SLIDER, WIDGET_SLIDER)
 #define CIRCULAR_SLIDER(w) (WIDGET_SLIDER==(w) && SLIDER_CIRCULAR==opts.sliderStyle)
 
 #define MODIFY_AGUA_X(A, X) (APPEARANCE_AGUA==(A) ?  (X) : (A))
@@ -205,9 +186,10 @@ enum {
 #define COLORED_BORDER_SIZE 3
 #define PROGRESS_CHUNK_WIDTH 10
 #define STRIPE_WIDTH 10
-#define DRAW_LIGHT_BORDER(SUKEN, WIDGET, APP) \
-    (!(SUKEN) && (GB_LIGHT==qtcGetGradient(APP, &opts)->border) && WIDGET_MENU_ITEM!=(WIDGET) && !IS_TROUGH(WIDGET) && \
-                          (WIDGET_DEF_BUTTON!=(WIDGET) || IND_COLORED!=opts.defBtnIndicator))
+#define DRAW_LIGHT_BORDER(SUKEN, WIDGET, APP)                           \
+    (!(SUKEN) && (qtcGetGradient(APP, &opts)->border == GB_LIGHT) &&    \
+     (WIDGET) != WIDGET_MENU_ITEM && !IS_TROUGH(WIDGET) &&              \
+     ((WIDGET) != WIDGET_DEF_BUTTON || opts.defBtnIndicator != IND_COLORED))
 
 #define DRAW_3D_FULL_BORDER(SUNKEN, APP) \
     (!(SUNKEN) && GB_3D_FULL==qtcGetGradient((APP), &opts)->border)
@@ -226,46 +208,38 @@ enum {
 #define CR_SMALL_SIZE 13
 #define CR_LARGE_SIZE 15
 
-#define TAB_APP(A)   (APPEARANCE_BEVELLED==(A) || APPEARANCE_SPLIT_GRADIENT==(A) ? APPEARANCE_GRADIENT : (A))
+#define TAB_APP(A)                                                      \
+    (qtcOneOf(A, APPEARANCE_BEVELLED, APPEARANCE_SPLIT_GRADIENT) ?      \
+     APPEARANCE_GRADIENT : (A))
 #define NORM_TAB_APP TAB_APP(opts.tabAppearance)
 #define SEL_TAB_APP  TAB_APP(opts.activeTabAppearance)
 
 #define SLIDER_MO_SHADE  (SHADE_SELECTED==opts.shadeSliders ? 1 : (SHADE_BLEND_SELECTED==opts.shadeSliders ? 0 : ORIGINAL_SHADE))
 #define SLIDER_MO_PLASTIK_BORDER (SHADE_SELECTED==opts.shadeSliders || SHADE_BLEND_SELECTED==opts.shadeSliders ? 2 : 1)
 #define SLIDER_MO_LEN    (SLIDER_TRIANGULAR==opts.sliderStyle ? 2 : (SHADE_SELECTED==opts.shadeSliders || SHADE_BLEND_SELECTED==opts.shadeSliders ? 4 : 3))
-#define SB_SLIDER_MO_LEN(A) ((A)<22 && !FULLLY_ROUNDED \
-                                    ? 2 \
-                                    : ((A)<32 || (SHADE_SELECTED!=opts.shadeSliders && SHADE_BLEND_SELECTED!=opts.shadeSliders) \
-                                        ? 4 \
-                                        : 6))
+#define SB_SLIDER_MO_LEN(A)                                             \
+    ((A) < 22 && !(opts.round >= ROUND_FULL) ? 2 :                      \
+     ((A) < 32 || qtcNoneOf(opts.shadeSliders, SHADE_SELECTED,          \
+                            SHADE_BLEND_SELECTED) ? 4 : 6))
 
 #define CR_MO_FILL          1
 #define MO_DEF_BTN          2
 #define MO_PLASTIK_DARK(W)  (WIDGET_DEF_BUTTON==(W) && IND_COLORED==opts.defBtnIndicator ? 3 : 2) /*? 2 : 1) */
 #define MO_PLASTIK_LIGHT(W) (WIDGET_DEF_BUTTON==(W) && IND_COLORED==opts.defBtnIndicator ? 4 : 1) /*? 2 : 0) */
 
-#define MO_STD_DARK(W)     (MO_GLOW==opts.coloredMouseOver \
-                                    ? 1 \
-                                    : MO_PLASTIK_DARK(W))
-#define MO_STD_LIGHT(W, S) (MO_GLOW==opts.coloredMouseOver \
-                                    ? 1 \
-                                    : MO_PLASTIK_LIGHT(W))
-
-#define FULLLY_ROUNDED     (opts.round>=ROUND_FULL)
-#define DO_EFFECT          (EFFECT_NONE!=opts.buttonEffect)
-#define SLIDER_GLOW        (DO_EFFECT && MO_GLOW==opts.coloredMouseOver /*&& SLIDER_TRIANGULAR!=opts.sliderStyle*/ ? 2 : 0)
-
-#define ENTRY_MO (opts.unifyCombo && opts.unifySpin)
-
+#define MO_STD_DARK(W)                                          \
+    (opts.coloredMouseOver == MO_GLOW ? 1 : MO_PLASTIK_DARK(W))
+#define MO_STD_LIGHT(W, S)                                              \
+    (opts.coloredMouseOver == MO_GLOW ? 1 : MO_PLASTIK_LIGHT(W))
 
 #define FOCUS_ALPHA              0.08
-#define FOCUS_GLOW_LINE_ALPHA    0.5
-#define BORDER_BLEND_ALPHA(W)    (WIDGET_ENTRY==(W) || WIDGET_SCROLLVIEW==(W) || WIDGET_SPIN==(W) || WIDGET_COMBO_BUTTON==(W) ? 0.4 : 0.7)
+#define BORDER_BLEND_ALPHA(W)                                   \
+    (qtcOneOf(W, WIDGET_ENTRY, WIDGET_SCROLLVIEW,               \
+              WIDGET_SPIN, WIDGET_COMBO_BUTTON) ? 0.4 : 0.7)
 
 #define ETCH_TOP_ALPHA           0.055
 #define ETCH_BOTTOM_ALPHA        0.1
 #define ETCH_RADIO_TOP_ALPHA     0.09
-#define ETCH_RADIO_BOTTOM_ALPHA  1.0
 
 #define RINGS_INNER_ALPHA(T) qtc_ring_alpha[IMG_PLAIN_RINGS==(T) ? 1 : 0] //(IMG_PLAIN_RINGS==opts.bgndImage.type ? 0.25 :  0.125)
 #define RINGS_OUTER_ALPHA    qtc_ring_alpha[2] //0.5
@@ -278,11 +252,6 @@ enum {
 #define RINGS_SQUARE_RADIUS      18.0
 #define RINGS_SQUARE_LARGE_SIZE  120.0
 #define RINGS_SQUARE_SMALL_SIZE  100.0
-
-#define MENU_AND_TOOLTIP_RADIUS   (opts.round>=ROUND_FULL ? 5.0 : 3.5)
-
-#define CUSTOM_BGND (!(IS_FLAT_BGND(opts.bgndAppearance)) || IMG_NONE!=opts.bgndImage.type || 100!=opts.bgndOpacity || 100!=opts.dlgOpacity)
-
 #define GLOW_PROG_ALPHA 0.55
 
 typedef enum {
@@ -307,8 +276,6 @@ typedef struct {
     GdkPixbuf *img;
 } QtCPixmap;
 
-#define BGND_IMG_ON_BORDER (IMG_FILE==opts.bgndImage.type && opts.bgndImage.onBorder)
-
 typedef enum {
     PP_TL,
     PP_TM,
@@ -421,67 +388,10 @@ typedef enum
     APP_ALLOW_NONE
 } EAppAllow;
 
-typedef enum
-{
-    APPEARANCE_CUSTOM1,
-    APPEARANCE_CUSTOM2,
-    APPEARANCE_CUSTOM3,
-    APPEARANCE_CUSTOM4,
-    APPEARANCE_CUSTOM5,
-    APPEARANCE_CUSTOM6,
-    APPEARANCE_CUSTOM7,
-    APPEARANCE_CUSTOM8,
-    APPEARANCE_CUSTOM9,
-    APPEARANCE_CUSTOM10,
-    APPEARANCE_CUSTOM11,
-    APPEARANCE_CUSTOM12,
-    APPEARANCE_CUSTOM13,
-    APPEARANCE_CUSTOM14,
-    APPEARANCE_CUSTOM15,
-    APPEARANCE_CUSTOM16,
-    APPEARANCE_CUSTOM17,
-    APPEARANCE_CUSTOM18,
-    APPEARANCE_CUSTOM19,
-    APPEARANCE_CUSTOM20,
-    APPEARANCE_CUSTOM21,
-    APPEARANCE_CUSTOM22,
-    APPEARANCE_CUSTOM23,
-
-        NUM_CUSTOM_GRAD,
-
-    APPEARANCE_FLAT = NUM_CUSTOM_GRAD,
-    APPEARANCE_RAISED,
-    APPEARANCE_DULL_GLASS,
-    APPEARANCE_SHINY_GLASS,
-    APPEARANCE_AGUA,
-    APPEARANCE_SOFT_GRADIENT,
-    APPEARANCE_GRADIENT,
-    APPEARANCE_HARSH_GRADIENT,
-    APPEARANCE_INVERTED,
-    APPEARANCE_DARK_INVERTED,
-    APPEARANCE_SPLIT_GRADIENT,
-    APPEARANCE_BEVELLED,
-        APPEARANCE_FADE, /* Only for poupmenu items! */
-        APPEARANCE_STRIPED = APPEARANCE_FADE, /* Only for windows  and menus */
-        APPEARANCE_NONE = APPEARANCE_FADE, /* Only for titlebars */
-        APPEARANCE_FILE,  /* Only for windows  and menus */
-        APPEARANCE_LV_BEVELLED, /* To be used only with qtcGetGradient */
-        APPEARANCE_AGUA_MOD,
-        APPEARANCE_LV_AGUA,
-    NUM_STD_APP = (APPEARANCE_LV_AGUA-NUM_CUSTOM_GRAD)+1
-} EAppearance;
-
-#define IS_SLIDER(W)        (WIDGET_SLIDER==(W) || WIDGET_SB_SLIDER==(W))
-#define IS_TROUGH(W)        (WIDGET_SLIDER_TROUGH==(W) || WIDGET_PBAR_TROUGH==(W) || WIDGET_TROUGH==(W) || WIDGET_FILLED_SLIDER_TROUGH==(W))
-#define IS_TOGGLE_BUTTON(W) (WIDGET_TOGGLE_BUTTON==(W) || WIDGET_CHECKBOX==(W))
-
-typedef enum
-{
-    CORNER_TL = 0x1,
-    CORNER_TR = 0x2,
-    CORNER_BR = 0x4,
-    CORNER_BL = 0x8
-} ECornerBits;
+#define IS_SLIDER(w) qtcOneOf(w, WIDGET_SLIDER, WIDGET_SB_SLIDER)
+#define IS_TROUGH(w) qtcOneOf(w, WIDGET_SLIDER_TROUGH, WIDGET_PBAR_TROUGH, \
+                              WIDGET_TROUGH, WIDGET_FILLED_SLIDER_TROUGH)
+#define IS_TOGGLE_BUTTON(W) qtcOneOf(W, WIDGET_TOGGLE_BUTTON, WIDGET_CHECKBOX)
 
 #define ROUNDED_NONE        0x0
 #define ROUNDED_TOP         (CORNER_TL|CORNER_TR)
@@ -545,8 +455,7 @@ typedef enum
     For menubars, we dont blend - so blend is selected, and selected is darken
     For check/radios - we dont blend, so blend is selected, and we dont allow darken
 */
-typedef enum
-{
+typedef enum {
     SHADE_NONE,
     SHADE_CUSTOM,
     SHADE_SELECTED,
@@ -555,15 +464,13 @@ typedef enum
     SHADE_WINDOW_BORDER
 } EShade;
 
-typedef enum
-{
+typedef enum {
     ECOLOR_BASE,
     ECOLOR_BACKGROUND,
     ECOLOR_DARK,
 } EColor;
 
-typedef enum
-{
+typedef enum {
     ROUND_NONE,
     ROUND_SLIGHT,
     ROUND_FULL,
@@ -571,27 +478,14 @@ typedef enum
     ROUND_MAX
 } ERound;
 
-typedef enum
-{
-    FRAME_NONE,
-    FRAME_PLAIN,
-    FRAME_LINE,
-    FRAME_SHADED,
-    FRAME_FADED
-} EFrame;
-
-typedef enum
-{
-    GB_LBL_BOLD     = 0x01,
-    GB_LBL_CENTRED  = 0x02,
-    GB_LBL_INSIDE   = 0x04,
-    GB_LBL_OUTSIDE  = 0x08
+typedef enum {
+    GB_LBL_BOLD = 0x01,
+    GB_LBL_CENTRED = 0x02,
+    GB_LBL_INSIDE = 0x04,
+    GB_LBL_OUTSIDE = 0x08
 } EGBLabel;
 
-#define NO_FRAME(A) (FRAME_NONE==(A) || FRAME_LINE==(A))
-
-typedef enum
-{
+typedef enum {
     MO_NONE,
     MO_COLORED,
     MO_COLORED_THICK,
@@ -599,16 +493,14 @@ typedef enum
     MO_GLOW
 } EMouseOver;
 
-typedef enum
-{
+typedef enum {
     STRIPE_NONE,
     STRIPE_PLAIN,
     STRIPE_DIAGONAL,
     STRIPE_FADE
 } EStripe;
 
-typedef enum
-{
+typedef enum {
     SLIDER_PLAIN,
     SLIDER_ROUND,
     SLIDER_PLAIN_ROTATED,
@@ -617,10 +509,7 @@ typedef enum
     SLIDER_CIRCULAR
 } ESliderStyle;
 
-#define ROTATED_SLIDER (SLIDER_PLAIN_ROTATED==opts.sliderStyle || SLIDER_ROUND_ROTATED==opts.sliderStyle)
-
-typedef enum
-{
+typedef enum {
     FOCUS_STANDARD,
     FOCUS_RECTANGLE,
     FOCUS_FULL,
@@ -629,29 +518,24 @@ typedef enum
     FOCUS_GLOW
 } EFocus;
 
-typedef enum
-{
+typedef enum {
     TAB_MO_TOP,
     TAB_MO_BOTTOM,
     TAB_MO_GLOW
 } ETabMo;
 
-typedef enum
-{
+typedef enum {
     GT_HORIZ,
     GT_VERT
 } EGradType;
 
-typedef enum
-{
+typedef enum {
     GLOW_NONE,
     GLOW_START,
     GLOW_MIDDLE,
     GLOW_END
 } EGlow;
 
-#define FULL_FOCUS     (FOCUS_FULL==opts.focus  || FOCUS_FILLED==opts.focus)
-
 enum
 {
     HIDE_NONE     = 0x00,
@@ -665,14 +549,6 @@ typedef struct {
            alpha;
 } GradientStop;
 
-typedef enum {
-    GB_NONE,
-    GB_LIGHT,
-    GB_3D,
-    GB_3D_FULL,
-    GB_SHINE
-} EGradientBorder;
-
 typedef struct {
     int titleHeight,
         toolTitleHeight,
@@ -711,9 +587,6 @@ typedef struct {
                      highlightTab,
                      roundAllTabs,
                      animatedProgress,
-#ifdef QTC_GTK2_ENABLE_PARENTLESS_DIALOG_FIX_SUPPORT
-                     fixParentlessDialogs,
-#endif
                      customMenuTextColor,
                      menubarMouseOver,
                      useHighlightForMenu,
@@ -822,7 +695,7 @@ typedef struct {
                      tbarBtnEffect;
     EScrollbar       scrollbarType;
     EFocus           focus;
-    color            customMenubarsColor,
+    GdkColor customMenubarsColor,
                      customSlidersColor,
                      customMenuNormTextColor,
                      customMenuSelTextColor,
@@ -846,19 +719,33 @@ typedef struct {
                      noBgndOpacityApps,
                      noMenuBgndOpacityApps,
                      noBgndImageApps;
-#ifdef QTC_GTK2_ENABLE_PARENTLESS_DIALOG_FIX_SUPPORT
-    Strings          noDlgFixApps;
-#endif
     Strings          noMenuStripeApps;
 } Options;
 
+void qtcSetupGradient(Gradient *grad, EGradientBorder border, int numStops, ...);
+const Gradient *qtcGetGradient(EAppearance app, const Options *opts);
+
+QTC_ALWAYS_INLINE static inline bool
+qtcDrawMenuBorder(const Options *opts)
+{
+    return (opts->menuBgndAppearance != APPEARANCE_FLAT &&
+            opts->version >= qtcMakeVersion(1, 7) &&
+            qtcUseBorder(qtcGetGradient(opts->menuBgndAppearance,
+                                        opts)->border));
+}
+
+QTC_ALWAYS_INLINE static inline bool
+qtcIsCustomBgnd(const Options *opts)
+{
+    return (!qtcIsFlatBgnd(opts->bgndAppearance) ||
+            opts->bgndImage.type != IMG_NONE ||
+            opts->bgndOpacity != 100 || opts->dlgOpacity != 100);
+}
+
 #include <qtcurve-utils/color.h>
 #define tint(COLA, COLB, FACTOR) qtcColorTint((COLA), (COLB), (FACTOR))
 #define midColor(COLA, COLB) qtcColorMix((COLA), (COLB), 0.5)
 
-void qtcSetupGradient(Gradient *grad, EGradientBorder border, int numStops, ...);
-const Gradient *qtcGetGradient(EAppearance app, const Options *opts);
-
 EAppearance qtcWidgetApp(EWidget w, const Options *opts);
 
 typedef enum {
@@ -868,18 +755,20 @@ typedef enum {
     RADIUS_ETCH
 } ERadius;
 
-#define MIN_ROUND_MAX_HEIGHT    12
-#define MIN_ROUND_MAX_WIDTH     24
+#define MIN_ROUND_MAX_HEIGHT 12
+#define MIN_ROUND_MAX_WIDTH 24
 #define BGND_SHINE_SIZE 300
-#define BGND_SHINE_STEPS  8
+#define BGND_SHINE_STEPS 8
 
-#define MIN_ROUND_FULL_SIZE     8
-#define MIN_ROUND_EXTRA_SIZE(W) (WIDGET_SPIN_UP==(W) || WIDGET_SPIN_DOWN==(W) || WIDGET_SPIN==(W) ? 7 : 14)
+#define MIN_ROUND_FULL_SIZE 8
+#define MIN_ROUND_EXTRA_SIZE(W)                                         \
+    (qtcOneOf(W, WIDGET_SPIN_UP, WIDGET_SPIN_DOWN, WIDGET_SPIN) ? 7 : 14)
 
-#define IS_MAX_ROUND_WIDGET(A) \
-            (WIDGET_STD_BUTTON==A || WIDGET_DEF_BUTTON==A || WIDGET_TOGGLE_BUTTON==A /*|| WIDGET_MENU_BUTTON==A*/)
-#define IS_EXTRA_ROUND_WIDGET(A) \
-            (A!=WIDGET_MENU_ITEM && A!=WIDGET_TAB_FRAME && A!=WIDGET_PBAR_TROUGH && A!=WIDGET_PROGRESSBAR)
+#define IS_MAX_ROUND_WIDGET(A)                                          \
+    qtcOneOf(A, WIDGET_STD_BUTTON, WIDGET_DEF_BUTTON, WIDGET_TOGGLE_BUTTON)
+#define IS_EXTRA_ROUND_WIDGET(A)                                        \
+    qtcNoneOf(A, WIDGET_MENU_ITEM, WIDGET_TAB_FRAME, WIDGET_PBAR_TROUGH, \
+              WIDGET_PROGRESSBAR)
 
 #define EXTRA_INNER_RADIUS   4
 #define EXTRA_OUTER_RADIUS   5
