@@ -1,22 +1,24 @@
- /*
-  QtCurve (C) Craig Drummond, 2003 - 2010 craig.p.drummond@gmail.com
-
-  ----
-
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public
-  License version 2 as published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; see the file COPYING.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
- */
+/*****************************************************************************
+ *   Copyright 2003 - 2010 Craig Drummond <craig.p.drummond@gmail.com>       *
+ *   Copyright 2013 - 2014 Yichao Yu <yyc1992@gmail.com>                     *
+ *                                                                           *
+ *   This program is free software; you can redistribute it and/or modify    *
+ *   it under the terms of the GNU Lesser General Public License as          *
+ *   published by the Free Software Foundation; either version 2.1 of the    *
+ *   License, or (at your option) version 3, or any later version accepted   *
+ *   by the membership of KDE e.V. (or its successor approved by the         *
+ *   membership of KDE e.V.), which shall act as a proxy defined in          *
+ *   Section 6 of version 3 of the license.                                  *
+ *                                                                           *
+ *   This program is distributed in the hope that it will be useful,         *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of          *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       *
+ *   Lesser General Public License for more details.                         *
+ *                                                                           *
+ *   You should have received a copy of the GNU Lesser General Public        *
+ *   License along with this library. If not,                                *
+ *   see <http://www.gnu.org/licenses/>.                                     *
+ *****************************************************************************/
 
 #include <qtcurve-utils/log.h>
 #include <qtcurve-utils/dirs.h>
@@ -52,7 +54,7 @@ static int c2h(char ch)
 
 #define ATOH(str) ((c2h(*str)<<4)+c2h(*(str+1)))
 
-void qtcSetRgb(color *col, const char *str)
+void qtcSetRgb(GdkColor *col, const char *str)
 {
     if (str && strlen(str)>6) {
         int offset = '#' == str[0] ? 1 : 0;
@@ -199,7 +201,9 @@ static EAppearance toAppearance(const char *str, EAppearance def, EAppAllow allo
     return def;
 }
 
-static EShade toShade(const char *str, bool allowMenu, EShade def, bool menuShade, color *col)
+static EShade
+toShade(const char *str, bool allowMenu, EShade def,
+        bool menuShade, GdkColor *col)
 {
     if(str && 0!=str[0])
     {
@@ -437,9 +441,8 @@ static bool toLvLines(const char *str, bool def)
 
 static EGradientBorder toGradientBorder(const char *str, bool *haveAlpha)
 {
-    if(str && 0!=str[0])
-    {
-        *haveAlpha=strstr(str, "-alpha") ? true : false;
+    if (str && str[0]) {
+        *haveAlpha = strstr(str, "-alpha") ? true : false;
         if(0==memcmp(str, "light", 5) || 0==memcmp(str, "true", 4))
             return GB_LIGHT;
         if(0==memcmp(str, "none", 4))
@@ -538,8 +541,7 @@ qtcGetWindowBorderSize(bool force)
             sizes.bottom=atoi(line);
             getline(&line, &len, f);
             sizes.sides=atoi(line);
-            if(line)
-                free(line);
+            qtcFree(line);
             fclose(f);
         }
         free(filename);
@@ -585,7 +587,7 @@ void qtcLoadBgndImage(QtCImage *img)
         {
             img->pixmap.img=0==img->width
                             ? gdk_pixbuf_new_from_file(determineFileName(img->pixmap.file), NULL)
-                            : gdk_pixbuf_new_from_file_at_scale(determineFileName(img->pixmap.file), img->width, img->height, FALSE, NULL);
+                            : gdk_pixbuf_new_from_file_at_scale(determineFileName(img->pixmap.file), img->width, img->height, false, NULL);
             if(img->pixmap.img && 0==img->width && img->pixmap.img)
             {
                 img->width=gdk_pixbuf_get_width(img->pixmap.img);
@@ -596,7 +598,7 @@ void qtcLoadBgndImage(QtCImage *img)
 }
 
 static void
-checkColor(EShade *s, color *c)
+checkColor(EShade *s, GdkColor *c)
 {
     if(SHADE_CUSTOM==*s && IS_BLACK(*c))
         *s=SHADE_NONE;
@@ -684,12 +686,11 @@ readVersionEntry(GHashTable *cfg, const char *key)
             : 0;
 }
 
-static gboolean
-readBoolEntry(GHashTable *cfg, const char *key, gboolean def)
+static bool
+readBoolEntry(GHashTable *cfg, const char *key, bool def)
 {
-    char *str=readStringEntry(cfg, key);
-
-    return str ? (0==memcmp(str, "true", 4) ? true : false) : def;
+    char *str = readStringEntry(cfg, key);
+    return str ? (memcmp(str, "true", 4) == 0 ? true : false) : def;
 }
 
 static void
@@ -736,9 +737,9 @@ readDoubleList(GHashTable *cfg, const char *key, double *list, int count)
 #define CFG_READ_COLOR(ENTRY) do {                        \
         const char *str = readStringEntry(cfg, #ENTRY);   \
         if (str && 0 != str[0]) {                         \
-            qtcSetRgb(&(opts->ENTRY), str);               \
+            qtcSetRgb(&opts->ENTRY, str);                 \
         } else {                                          \
-            opts->ENTRY=def->ENTRY;                       \
+            opts->ENTRY = def->ENTRY;                     \
         }                                                 \
     } while (0)
 
@@ -764,7 +765,7 @@ readDoubleList(GHashTable *cfg, const char *key, double *list, int count)
     } while (0)
 
 #define CFG_READ_STRING_LIST(ENTRY) do {                 \
-        const gchar *str = readStringEntry(cfg, #ENTRY); \
+        const char *str = readStringEntry(cfg, #ENTRY); \
         if (str && 0 != str[0]) {                        \
             opts->ENTRY = g_strsplit(str, ",", -1);      \
         } else if (def->ENTRY) {                         \
@@ -918,24 +919,29 @@ checkAppearance(EAppearance *ap, Options *opts)
 
 void qtcDefaultSettings(Options *opts);
 
-static void copyGradients(Options *src, Options *dest)
+static void
+copyGradients(Options *src, Options *dest)
 {
-    if(src && dest && src!=dest)
-    {
+    if (src && dest && src != dest) {
         int i;
 
-        for(i=0; i<NUM_CUSTOM_GRAD; ++i)
-            if(src->customGradient[i] && src->customGradient[i]->numStops>0)
-            {
-                dest->customGradient[i]=malloc(sizeof(Gradient));
-                dest->customGradient[i]->numStops=src->customGradient[i]->numStops;
-                dest->customGradient[i]->stops=malloc(sizeof(GradientStop) * dest->customGradient[i]->numStops);
-                memcpy(dest->customGradient[i]->stops, src->customGradient[i]->stops,
-                        sizeof(GradientStop) * dest->customGradient[i]->numStops);
-                dest->customGradient[i]->border=src->customGradient[i]->border;
+        for (i = 0;i < NUM_CUSTOM_GRAD;++i) {
+            if (src->customGradient[i] &&
+                src->customGradient[i]->numStops > 0) {
+                dest->customGradient[i] = qtcNew(Gradient);
+                dest->customGradient[i]->numStops =
+                    src->customGradient[i]->numStops;
+                dest->customGradient[i]->stops =
+                    qtcNew(GradientStop, dest->customGradient[i]->numStops);
+                memcpy(dest->customGradient[i]->stops,
+                       src->customGradient[i]->stops,
+                       sizeof(GradientStop) * dest->customGradient[i]->numStops);
+                dest->customGradient[i]->border =
+                    src->customGradient[i]->border;
+            } else {
+                dest->customGradient[i] = NULL;
             }
-            else
-                dest->customGradient[i]=NULL;
+        }
     }
 }
 
@@ -948,10 +954,6 @@ static void copyOpts(Options *src, Options *dest)
         dest->noBgndOpacityApps=src->noBgndOpacityApps;
         dest->noMenuBgndOpacityApps=src->noMenuBgndOpacityApps;
         dest->noBgndImageApps=src->noBgndImageApps;
-#ifdef QTC_GTK2_ENABLE_PARENTLESS_DIALOG_FIX_SUPPORT
-        dest->noDlgFixApps=src->noDlgFixApps;
-        src->noDlgFixApps=NULL;
-#endif
         dest->noMenuStripeApps=src->noMenuStripeApps;
         src->noBgndGradientApps=src->noBgndOpacityApps=src->noMenuBgndOpacityApps=src->noBgndImageApps=src->noMenuStripeApps=NULL;
         memcpy(dest->customShades, src->customShades,
@@ -976,22 +978,16 @@ static void freeOpts(Options *opts)
             g_strfreev(opts->noMenuBgndOpacityApps);
         if(opts->noBgndImageApps)
             g_strfreev(opts->noBgndImageApps);
-#ifdef QTC_GTK2_ENABLE_PARENTLESS_DIALOG_FIX_SUPPORT
-        if(opts->noDlgFixApps)
-            g_strfreev(opts->noDlgFixApps);
-        opts->noDlgFixApps=NULL
-#endif
         if(opts->noMenuStripeApps)
             g_strfreev(opts->noMenuStripeApps);
         opts->noBgndGradientApps=opts->noBgndOpacityApps=opts->noMenuBgndOpacityApps=opts->noBgndImageApps=opts->noMenuStripeApps=NULL;
-        for(i=0; i<NUM_CUSTOM_GRAD; ++i)
-            if(opts->customGradient[i])
-            {
-                if(opts->customGradient[i]->stops)
-                    free(opts->customGradient[i]->stops);
+        for (i = 0;i < NUM_CUSTOM_GRAD;++i) {
+            if (opts->customGradient[i]) {
+                qtcFree(opts->customGradient[i]->stops);
                 free(opts->customGradient[i]);
-                opts->customGradient[i]=NULL;
+                opts->customGradient[i] = NULL;
             }
+        }
     }
 }
 
@@ -1200,40 +1196,32 @@ void qtcCheckConfig(Options *opts)
 bool qtcReadConfig(const char *file, Options *opts, Options *defOpts)
 {
     bool checkImages=true;
-    if(!file)
-    {
-        const char *env=getenv("QTCURVE_CONFIG_FILE");
-
-        if(NULL!=env)
+    if (!file) {
+        const char *env = getenv("QTCURVE_CONFIG_FILE");
+        if (env && *env)
             return qtcReadConfig(env, opts, defOpts);
-        else {
-            char *filename = qtcCatStrs(qtcConfDir(), CONFIG_FILE);
-            bool rv = false;
-            if (!qtcIsRegFile(filename)) {
-                filename = qtcFillStrs(filename, qtcConfDir(), OLD_CONFIG_FILE);
-            }
-            rv = qtcReadConfig(filename, opts, defOpts);
-            free(filename);
-            return rv;
+
+        char *filename = qtcCatStrs(qtcConfDir(), CONFIG_FILE);
+        bool rv = false;
+        if (!qtcIsRegFile(filename)) {
+            filename = qtcFillStrs(filename, qtcConfDir(),
+                                   "/../" OLD_CONFIG_FILE);
         }
-    }
-    else {
+        rv = qtcReadConfig(filename, opts, defOpts);
+        free(filename);
+        return rv;
+    } else {
         GHashTable *cfg=loadConfig(file);
 
-        if(cfg)
-        {
-            int     i;
-
+        if (cfg) {
             opts->version=readVersionEntry(cfg, VERSION_KEY);
 
             Options newOpts;
             Options *def=&newOpts;
-#ifdef QTC_GTK2_ENABLE_PARENTLESS_DIALOG_FIX_SUPPORT
-            opts->noDlgFixApps=NULL;
-#endif
             opts->noBgndGradientApps=opts->noBgndOpacityApps=opts->noMenuBgndOpacityApps=opts->noBgndImageApps=opts->noMenuStripeApps=NULL;
-            for(i=0; i<NUM_CUSTOM_GRAD; ++i)
-                opts->customGradient[i]=NULL;
+            for (int i = 0;i < NUM_CUSTOM_GRAD;++i) {
+                opts->customGradient[i] = NULL;
+            }
 
             if(defOpts)
                 copyOpts(defOpts, &newOpts);
@@ -1330,20 +1318,16 @@ bool qtcReadConfig(const char *file, Options *opts, Options *defOpts)
                 CFG_READ_EFFECT(tbarBtnEffect);
             }
             CFG_READ_APPEARANCE_PIXMAP(bgndAppearance, APP_ALLOW_STRIPED,
-                                       &(opts->bgndPixmap), checkImages);
+                                       &opts->bgndPixmap, checkImages);
             CFG_READ_GRAD_TYPE(bgndGrad);
             CFG_READ_GRAD_TYPE(menuBgndGrad);
             CFG_READ_INT_BOOL(lighterPopupMenuBgnd, def->lighterPopupMenuBgnd);
             CFG_READ_APPEARANCE_PIXMAP(menuBgndAppearance, APP_ALLOW_STRIPED,
-                                       &(opts->menuBgndPixmap), checkImages);
+                                       &opts->menuBgndPixmap, checkImages);
 
             if(APPEARANCE_FLAT==opts->menuBgndAppearance && 0==opts->lighterPopupMenuBgnd && opts->version<qtcMakeVersion(1, 7))
                 opts->menuBgndAppearance=APPEARANCE_RAISED;
 
-#ifdef QTC_GTK2_ENABLE_PARENTLESS_DIALOG_FIX_SUPPORT
-            CFG_READ_BOOL(fixParentlessDialogs);
-            CFG_READ_STRING_LIST(noDlgFixApps);
-#endif
             CFG_READ_STRIPE(stripedProgress);
             CFG_READ_SLIDER(sliderStyle);
             CFG_READ_BOOL(animatedProgress);
@@ -1489,8 +1473,7 @@ bool qtcReadConfig(const char *file, Options *opts, Options *defOpts)
             readDoubleList(cfg, "customShades", opts->customShades, QTC_NUM_STD_SHADES);
             readDoubleList(cfg, "customAlphas", opts->customAlphas, NUM_STD_ALPHAS);
 
-            for(i=0; i<NUM_CUSTOM_GRAD; ++i)
-            {
+            for (int i = 0;i < NUM_CUSTOM_GRAD;++i) {
                 char gradKey[18];
                 char *str;
 
@@ -1504,10 +1487,8 @@ bool qtcReadConfig(const char *file, Options *opts, Options *defOpts)
                         if(','==str[j])
                             comma++;
 
-                    if(comma && opts->customGradient[i])
-                    {
-                        if(opts->customGradient[i]->stops)
-                            free(opts->customGradient[i]->stops);
+                    if (comma && opts->customGradient[i]) {
+                        qtcFree(opts->customGradient[i]->stops);
                         free(opts->customGradient[i]);
                         opts->customGradient[i]=0L;
                     }
@@ -1516,20 +1497,21 @@ bool qtcReadConfig(const char *file, Options *opts, Options *defOpts)
                     {
                         char *c=strchr(str, ',');
 
-                        if(c)
-                        {
-                            bool            haveAlpha=false;
-                            EGradientBorder border=toGradientBorder(str, &haveAlpha);
-                            int             parts=haveAlpha ? 3 : 2;
-                            bool            ok=0==comma%parts;
+                        if (c) {
+                            bool haveAlpha = false;
+                            EGradientBorder border =
+                                toGradientBorder(str, &haveAlpha);
+                            int parts = haveAlpha ? 3 : 2;
+                            bool ok = 0 == comma % parts;
 
-                            *c='\0';
+                            *c = '\0';
 
-                            if(ok)
-                            {
-                                opts->customGradient[i]=malloc(sizeof(Gradient));
-                                opts->customGradient[i]->numStops=comma/parts;
-                                opts->customGradient[i]->stops=malloc(sizeof(GradientStop) * opts->customGradient[i]->numStops);
+                            if (ok) {
+                                opts->customGradient[i] = qtcNew(Gradient);
+                                opts->customGradient[i]->numStops = comma / parts;
+                                opts->customGradient[i]->stops =
+                                    qtcNew(GradientStop,
+                                           opts->customGradient[i]->numStops);
                                 opts->customGradient[i]->border=border;
                                 str=c+1;
                                 for(j=0; j<comma && str && ok; j+=parts)
@@ -1587,16 +1569,16 @@ bool qtcReadConfig(const char *file, Options *opts, Options *defOpts)
                                     if(opts->customGradient[i]->stops[opts->customGradient[i]->numStops-1].pos<0.999)
                                         addEnd=1;
 
-                                    if(addStart || addEnd)
-                                    {
-                                        int          newSize=opts->customGradient[i]->numStops+addStart+addEnd;
-                                        GradientStop *stops=malloc(sizeof(GradientStop) * newSize);
-
-                                        if(addStart)
-                                        {
-                                            stops[0].pos=0.0;
-                                            stops[0].val=1.0;
-                                            stops[0].alpha=1.0;
+                                    if (addStart || addEnd) {
+                                        int newSize =
+                                            (opts->customGradient[i]->numStops +
+                                             addStart + addEnd);
+                                        GradientStop *stops =
+                                            qtcNew(GradientStop, newSize);
+                                        if (addStart) {
+                                            stops[0].pos = 0.0;
+                                            stops[0].val = 1.0;
+                                            stops[0].alpha = 1.0;
                                         }
                                         memcpy(&stops[addStart], opts->customGradient[i]->stops, sizeof(GradientStop) * opts->customGradient[i]->numStops);
                                         if(addEnd)
@@ -1609,9 +1591,7 @@ bool qtcReadConfig(const char *file, Options *opts, Options *defOpts)
                                         free(opts->customGradient[i]->stops);
                                         opts->customGradient[i]->stops=stops;
                                     }
-                                }
-                                else
-                                {
+                                } else {
                                     free(opts->customGradient[i]->stops);
                                     free(opts->customGradient[i]);
                                     opts->customGradient[i]=0L;
@@ -1624,13 +1604,10 @@ bool qtcReadConfig(const char *file, Options *opts, Options *defOpts)
 
             qtcCheckConfig(opts);
 
-            if(!defOpts)
-            {
-                int i;
-
-                for(i=0; i<NUM_CUSTOM_GRAD; ++i)
-                    if(def->customGradient[i])
-                        free(def->customGradient[i]);
+            if (!defOpts) {
+                for (int i = 0;i < NUM_CUSTOM_GRAD;++i) {
+                    qtcFree(def->customGradient[i]);
+                }
             }
             releaseConfig(cfg);
             freeOpts(defOpts);
@@ -1653,23 +1630,22 @@ static const char * getSystemConfigFile()
 {
     static const char * constFiles[]={ /*"/etc/qt4/"OLD_CONFIG_FILE, "/etc/qt3/"OLD_CONFIG_FILE, "/etc/qt/"OLD_CONFIG_FILE,*/ "/etc/"OLD_CONFIG_FILE, NULL };
 
-    int i;
-
-    for(i=0; constFiles[i]; ++i)
-        if (qtcIsRegFile(constFiles[i]))
+    for (int i = 0;constFiles[i];++i) {
+        if (qtcIsRegFile(constFiles[i])) {
             return constFiles[i];
+        }
+    }
     return NULL;
 }
 
 void qtcDefaultSettings(Options *opts)
 {
     /* Set hard-coded defaults... */
-    int i;
-
-    for(i=0; i<NUM_CUSTOM_GRAD; ++i)
-        opts->customGradient[i]=0L;
-    opts->customGradient[APPEARANCE_CUSTOM1]=malloc(sizeof(Gradient));
-    opts->customGradient[APPEARANCE_CUSTOM2]=malloc(sizeof(Gradient));
+    for (int i = 0;i < NUM_CUSTOM_GRAD;++i) {
+        opts->customGradient[i] = NULL;
+    }
+    opts->customGradient[APPEARANCE_CUSTOM1] = qtcNew(Gradient);
+    opts->customGradient[APPEARANCE_CUSTOM2] = qtcNew(Gradient);
     qtcSetupGradient(opts->customGradient[APPEARANCE_CUSTOM1], GB_3D,3,0.0,1.2,0.5,1.0,1.0,1.0);
     qtcSetupGradient(opts->customGradient[APPEARANCE_CUSTOM2], GB_3D,3,0.0,0.9,0.5,1.0,1.0,1.0);
     opts->customShades[0]=1.16;
@@ -1744,10 +1720,6 @@ void qtcDefaultSettings(Options *opts)
     opts->toolbarBorders=TB_NONE;
     opts->toolbarSeparators=LINE_SUNKEN;
     opts->splitters=LINE_1DOT;
-#ifdef QTC_GTK2_ENABLE_PARENTLESS_DIALOG_FIX_SUPPORT
-    opts->fixParentlessDialogs=false;
-    opts->noDlgFixApps=NULL;
-#endif
     opts->customMenuTextColor=false;
     opts->coloredMouseOver=MO_GLOW;
     opts->menubarMouseOver=true;
@@ -1820,10 +1792,10 @@ void qtcDefaultSettings(Options *opts)
     opts->bgndOpacity = opts->dlgOpacity = opts->menuBgndOpacity = 100;
     opts->gtkComboMenus=false;
     opts->noBgndGradientApps=NULL;
-    opts->noBgndOpacityApps=g_strsplit("inkscape,sonata,totem,vmware,vmplayer",",", -1);;
+    opts->noBgndOpacityApps=g_strsplit("sonata,totem,vmware,vmplayer",",", -1);;
     opts->noBgndImageApps=NULL;
     opts->noMenuStripeApps=g_strsplit("gtk",",", -1);
-    opts->noMenuBgndOpacityApps=g_strsplit("inkscape,sonata,totem,vmware,vmplayer,gtk",",", -1);
+    opts->noMenuBgndOpacityApps=g_strsplit("sonata,totem,vmware,vmplayer,gtk",",", -1);
 /*
     opts->setDialogButtonOrder=false;
 */
@@ -1841,13 +1813,12 @@ void qtcDefaultSettings(Options *opts)
     opts->titlebarAppearance=APPEARANCE_CUSTOM1;
     opts->inactiveTitlebarAppearance=APPEARANCE_CUSTOM1;
     /* Read system config file... */
-    {
-    static const char * systemFilename=NULL;
+    static const char *systemFilename = NULL;
 
-    if(!systemFilename)
-        systemFilename=getSystemConfigFile();
-
-    if(systemFilename)
+    if (!systemFilename) {
+        systemFilename = getSystemConfigFile();
+    }
+    if (systemFilename) {
         qtcReadConfig(systemFilename, opts, opts);
     }
 }
