@@ -1,37 +1,38 @@
-/*
-  QtCurve (C) Craig Drummond, 2003 - 2010 craig.p.drummond@gmail.com
-
-  ----
-
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public
-  License version 2 as published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; see the file COPYING.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
-*/
+/*****************************************************************************
+ *   Copyright 2003 - 2010 Craig Drummond <craig.p.drummond@gmail.com>       *
+ *   Copyright 2013 - 2014 Yichao Yu <yyc1992@gmail.com>                     *
+ *                                                                           *
+ *   This program is free software; you can redistribute it and/or modify    *
+ *   it under the terms of the GNU Lesser General Public License as          *
+ *   published by the Free Software Foundation; either version 2.1 of the    *
+ *   License, or (at your option) version 3, or any later version accepted   *
+ *   by the membership of KDE e.V. (or its successor approved by the         *
+ *   membership of KDE e.V.), which shall act as a proxy defined in          *
+ *   Section 6 of version 3 of the license.                                  *
+ *                                                                           *
+ *   This program is distributed in the hope that it will be useful,         *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of          *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       *
+ *   Lesser General Public License for more details.                         *
+ *                                                                           *
+ *   You should have received a copy of the GNU Lesser General Public        *
+ *   License along with this library. If not,                                *
+ *   see <http://www.gnu.org/licenses/>.                                     *
+ *****************************************************************************/
 
 #include <qtcurve-utils/x11qtc.h>
-#include <qtcurve-utils/gtkutils.h>
+#include <qtcurve-utils/x11wrap.h>
+#include <qtcurve-utils/gtkprops.h>
 #include <qtcurve-utils/log.h>
+#include <qtcurve-cairo/utils.h>
 
 #include <gdk/gdkkeysyms.h>
 #include <gdk/gdkx.h>
-#include <stdlib.h>
-#include "compatability.h"
 #include <common/common.h>
 #include <common/config_file.h>
 #include "qt_settings.h"
 #include "window.h"
 #include "menu.h"
-#include <string.h>
 
 extern Options opts;
 
@@ -58,10 +59,10 @@ qtcWindowLookupHash(void *hash, gboolean create)
     rv = (QtCWindow*)g_hash_table_lookup(qtcWindowTable, hash);
 
     if (!rv && create) {
-        rv = (QtCWindow*)malloc(sizeof(QtCWindow));
+        rv = qtcNew(QtCWindow);
         rv->width = rv->height = rv->timer = 0;
         rv->widget = NULL;
-        rv->locked = FALSE;
+        rv->locked = false;
         g_hash_table_insert(qtcWindowTable, hash, rv);
         rv = g_hash_table_lookup(qtcWindowTable, hash);
     }
@@ -72,10 +73,12 @@ static void
 qtcWindowRemoveFromHash(void *hash)
 {
     if (qtcWindowTable) {
-        QtCWindow *tv = qtcWindowLookupHash(hash, FALSE);
+        QtCWindow *tv = qtcWindowLookupHash(hash, false);
         if (tv) {
-            if (tv->timer)
+            if (tv->timer) {
                 g_source_remove(tv->timer);
+                g_object_unref(G_OBJECT(tv->widget));
+            }
             g_hash_table_remove(qtcWindowTable, hash);
         }
     }
@@ -85,45 +88,45 @@ static void
 qtcWindowCleanup(GtkWidget *widget)
 {
     if (widget) {
-        GObject *obj = G_OBJECT(widget);
-        if (!(IS_FLAT_BGND(opts.bgndAppearance)) ||
-            IMG_NONE!=opts.bgndImage.type) {
+        QTC_DEF_WIDGET_PROPS(props, widget);
+        if (!(qtcIsFlatBgnd(opts.bgndAppearance)) ||
+            opts.bgndImage.type != IMG_NONE) {
             qtcWindowRemoveFromHash(widget);
-            qtcDisconnectFromData(obj, "QTC_WINDOW_CONFIGURE_ID");
-            qtcDisconnectFromData(obj, "QTC_WINDOW_DESTROY_ID");
-            qtcDisconnectFromData(obj, "QTC_WINDOW_STYLE_SET_ID");
+            qtcDisconnectFromProp(props, windowConfigure);
         }
+        qtcDisconnectFromProp(props, windowDestroy);
+        qtcDisconnectFromProp(props, windowStyleSet);
         if ((opts.menubarHiding & HIDE_KEYBOARD) ||
             (opts.statusbarHiding & HIDE_KEYBOARD))
-            qtcDisconnectFromData(obj, "QTC_WINDOW_KEY_RELEASE_ID");
+            qtcDisconnectFromProp(props, windowKeyRelease);
         if ((opts.menubarHiding & HIDE_KWIN) ||
             (opts.statusbarHiding & HIDE_KWIN))
-            qtcDisconnectFromData(obj, "QTC_WINDOW_MAP_ID");
+            qtcDisconnectFromProp(props, windowMap);
         if (opts.shadeMenubarOnlyWhenActive || BLEND_TITLEBAR ||
             opts.menubarHiding || opts.statusbarHiding)
-            qtcDisconnectFromData(obj, "QTC_WINDOW_CLIENT_EVENT_ID");
-        g_object_steal_data(obj, "QTC_WINDOW_HACK_SET");
+            qtcDisconnectFromProp(props, windowClientEvent);
+        qtcWidgetProps(props)->windowHacked = false;
     }
 }
 
 static gboolean
-qtcWindowStyleSet(GtkWidget *widget, GtkStyle *prev_style, gpointer data)
+qtcWindowStyleSet(GtkWidget *widget, GtkStyle *prev_style, void *data)
 {
     QTC_UNUSED(prev_style);
     QTC_UNUSED(data);
     qtcWindowCleanup(widget);
-    return FALSE;
+    return false;
 }
 
 static gboolean qtcWindowToggleMenuBar(GtkWidget *widget);
 static gboolean qtcWindowToggleStatusBar(GtkWidget *widget);
 
 static gboolean
-qtcWindowClientEvent(GtkWidget *widget, GdkEventClient *event, gpointer data)
+qtcWindowClientEvent(GtkWidget *widget, GdkEventClient *event, void *data)
 {
     QTC_UNUSED(data);
     if (gdk_x11_atom_to_xatom(event->message_type) ==
-        qtc_x11_atoms[QTC_X11_ATOM_QTC_ACTIVE_WINDOW]) {
+        qtc_x11_qtc_active_window) {
         if (event->data.l[0]) {
             qtcCurrentActiveWindow = widget;
         } else if (qtcCurrentActiveWindow == widget) {
@@ -131,7 +134,7 @@ qtcWindowClientEvent(GtkWidget *widget, GdkEventClient *event, gpointer data)
         }
         gtk_widget_queue_draw(widget);
     } else if (gdk_x11_atom_to_xatom(event->message_type) ==
-               qtc_x11_atoms[QTC_X11_ATOM_QTC_TITLEBAR_SIZE]) {
+               qtc_x11_qtc_titlebar_size) {
         qtcGetWindowBorderSize(true);
         GtkWidget *menubar = qtcWindowGetMenuBar(widget, 0);
 
@@ -139,27 +142,27 @@ qtcWindowClientEvent(GtkWidget *widget, GdkEventClient *event, gpointer data)
             gtk_widget_queue_draw(menubar);
         }
     } else if (gdk_x11_atom_to_xatom(event->message_type) ==
-               qtc_x11_atoms[QTC_X11_ATOM_QTC_TOGGLE_MENUBAR]) {
+               qtc_x11_qtc_toggle_menubar) {
         if (opts.menubarHiding & HIDE_KWIN && qtcWindowToggleMenuBar(widget)) {
             gtk_widget_queue_draw(widget);
         }
     } else if (gdk_x11_atom_to_xatom(event->message_type) ==
-               qtc_x11_atoms[QTC_X11_ATOM_QTC_TOGGLE_STATUSBAR]) {
+               qtc_x11_qtc_toggle_statusbar) {
         if (opts.statusbarHiding & HIDE_KWIN &&
             qtcWindowToggleStatusBar(widget)) {
             gtk_widget_queue_draw(widget);
         }
     }
-    return FALSE;
+    return false;
 }
 
 static gboolean
-qtcWindowDestroy(GtkWidget *widget, GdkEvent *event, gpointer data)
+qtcWindowDestroy(GtkWidget *widget, GdkEvent *event, void *data)
 {
     QTC_UNUSED(event);
     QTC_UNUSED(data);
     qtcWindowCleanup(widget);
-    return FALSE;
+    return false;
 }
 
 gboolean
@@ -172,17 +175,15 @@ qtcWindowIsActive(GtkWidget *widget)
 static gboolean
 qtcWindowSizeRequest(GtkWidget *widget)
 {
-    if (widget && (!(IS_FLAT_BGND(opts.bgndAppearance)) ||
+    if (widget && (!(qtcIsFlatBgnd(opts.bgndAppearance)) ||
                    IMG_NONE != opts.bgndImage.type)) {
-        GtkAllocation alloc = qtcWidgetGetAllocation(widget);
-        GdkRectangle rect;
-        rect.x = 0;
-        rect.y = 0;
-        if (IS_FLAT(opts.bgndAppearance) &&
+        QtcRect alloc = qtcWidgetGetAllocation(widget);
+        QtcRect rect = {0, 0, 0, 0};
+        if (qtcIsFlat(opts.bgndAppearance) &&
             IMG_NONE != opts.bgndImage.type) {
             EPixPos pos = (IMG_FILE == opts.bgndImage.type ?
                            opts.bgndImage.pos : PP_TR);
-            if (IMG_FILE == opts.bgndImage.type) {
+            if (opts.bgndImage.type == IMG_FILE) {
                 qtcLoadBgndImage(&opts.bgndImage);
             }
             switch (pos) {
@@ -193,7 +194,7 @@ qtcWindowSizeRequest(GtkWidget *widget)
             case PP_TM:
             case PP_TR:
                 rect.width = alloc.width;
-                rect.height = (IMG_FILE == opts.bgndImage.type ?
+                rect.height = (opts.bgndImage.type == IMG_FILE ?
                                opts.bgndImage.height :
                                RINGS_HEIGHT(opts.bgndImage.type)) + 1;
                 break;
@@ -219,20 +220,21 @@ qtcWindowSizeRequest(GtkWidget *widget)
         } else {
             rect.width = alloc.width, rect.height = alloc.height;
         }
-        gdk_window_invalidate_rect(gtk_widget_get_window(widget), &rect, FALSE);
+        gdk_window_invalidate_rect(gtk_widget_get_window(widget),
+                                   (GdkRectangle*)&rect, false);
     }
-    return FALSE;
+    return false;
 }
 
 static gboolean
-qtcWindowDelayedUpdate(gpointer user_data)
+qtcWindowDelayedUpdate(void *user_data)
 {
     QtCWindow *window = (QtCWindow*)user_data;
 
     if (window) {
         if (window->locked) {
-            window->locked = FALSE;
-            return TRUE;
+            window->locked = false;
+            return true;
         } else {
             g_source_remove(window->timer);
             window->timer = 0;
@@ -240,14 +242,15 @@ qtcWindowDelayedUpdate(gpointer user_data)
             gdk_threads_enter();
             qtcWindowSizeRequest(window->widget);
             gdk_threads_leave();
-            return FALSE;
+            g_object_unref(G_OBJECT(window->widget));
+            return false;
         }
     }
-    return FALSE;
+    return false;
 }
 
 static gboolean
-qtcWindowConfigure(GtkWidget *widget, GdkEventConfigure *event, gpointer data)
+qtcWindowConfigure(GtkWidget *widget, GdkEventConfigure *event, void *data)
 {
     QTC_UNUSED(widget);
     QtCWindow *window = (QtCWindow*)data;
@@ -259,14 +262,15 @@ qtcWindowConfigure(GtkWidget *widget, GdkEventConfigure *event, gpointer data)
 
         // schedule delayed timeOut
         if (!window->timer) {
+            g_object_ref(G_OBJECT(window->widget));
             window->timer =
-                g_timeout_add(50, (GSourceFunc)qtcWindowDelayedUpdate, window);
-            window->locked = FALSE;
+                g_timeout_add(50, qtcWindowDelayedUpdate, window);
+            window->locked = false;
         } else {
-            window->locked = TRUE;
+            window->locked = true;
         }
     }
-    return FALSE;
+    return false;
 }
 
 static gboolean
@@ -284,9 +288,7 @@ qtcWindowGetMenuBar(GtkWidget *parent, int level)
         /* && gtk_widget_get_realized(parent)*/) {
         GtkWidget *rv = NULL;
         GList *children = gtk_container_get_children(GTK_CONTAINER(parent));
-        GList *child = children;
-
-        for (;child && !rv;child = child->next) {
+        for (GList *child = children;child && !rv;child = child->next) {
             GtkWidget *boxChild = (GtkWidget*)child->data;
 
             if (GTK_IS_MENU_BAR(boxChild)) {
@@ -296,8 +298,9 @@ qtcWindowGetMenuBar(GtkWidget *parent, int level)
             }
         }
 
-        if (children)
+        if (children) {
             g_list_free(children);
+        }
         return rv;
     }
     return NULL;
@@ -310,9 +313,7 @@ qtcWindowGetStatusBar(GtkWidget *parent, int level)
         /* && gtk_widget_get_realized(parent)*/) {
         GtkWidget *rv = NULL;
         GList *children = gtk_container_get_children(GTK_CONTAINER(parent));
-        GList *child = children;
-
-        for(;child && !rv;child = child->next) {
+        for(GList *child = children;child && !rv;child = child->next) {
             GtkWidget *boxChild = (GtkWidget*)child->data;
 
             if (GTK_IS_STATUSBAR(boxChild)) {
@@ -390,25 +391,25 @@ qtcWindowToggleMenuBar(GtkWidget *widget)
 
         qtcMenuEmitSize(menuBar, size);
         qtcWindowMenuBarDBus(widget, size);
-        return TRUE;
+        return true;
     }
-    return FALSE;
+    return false;
 }
 
 gboolean
 qtcWindowSetStatusBarProp(GtkWidget *w)
 {
-    if (w && !g_object_get_data(G_OBJECT(w), QTC_STATUSBAR)) {
+    QTC_DEF_WIDGET_PROPS(props, w);
+    if (w && !qtcWidgetProps(props)->statusBarSet) {
         GtkWindow *topLevel = GTK_WINDOW(gtk_widget_get_toplevel(w));
         xcb_window_t wid =
             GDK_WINDOW_XID(gtk_widget_get_window(GTK_WIDGET(topLevel)));
 
-        g_object_set_data(G_OBJECT(w), QTC_STATUSBAR, GINT_TO_POINTER(1));
+        qtcWidgetProps(props)->statusBarSet = true;
         qtcX11SetStatusBar(wid);
-        qtcX11Flush();
-        return TRUE;
+        return true;
     }
-    return FALSE;
+    return false;
 }
 
 static gboolean
@@ -417,7 +418,7 @@ qtcWindowToggleStatusBar(GtkWidget *widget)
     GtkWidget *statusBar = qtcWindowGetStatusBar(widget, 0);
 
     if (statusBar) {
-        gboolean state=gtk_widget_get_visible(statusBar);
+        bool state = gtk_widget_get_visible(statusBar);
         qtcSetStatusBarHidden(qtSettings.appName, state);
         if (state) {
             gtk_widget_hide(statusBar);
@@ -425,16 +426,16 @@ qtcWindowToggleStatusBar(GtkWidget *widget)
             gtk_widget_show(statusBar);
         }
         qtcWindowStatusBarDBus(widget, state);
-        return TRUE;
+        return true;
     }
-    return FALSE;
+    return false;
 }
 
 static void
 qtcWindowSetProperties(GtkWidget *w, unsigned short opacity)
 {
     GtkWindow *topLevel = GTK_WINDOW(gtk_widget_get_toplevel(w));
-    unsigned long prop = (IS_FLAT_BGND(opts.bgndAppearance) ?
+    unsigned long prop = (qtcIsFlatBgnd(opts.bgndAppearance) ?
                           (IMG_NONE != opts.bgndImage.type ?
                            APPEARANCE_RAISED : APPEARANCE_FLAT) :
                           opts.bgndAppearance) & 0xFF;
@@ -444,57 +445,54 @@ qtcWindowSetProperties(GtkWidget *w, unsigned short opacity)
     xcb_window_t wid =
         GDK_WINDOW_XID(gtk_widget_get_window(GTK_WIDGET(topLevel)));
 
-    if (opacity != 100)
+    if (opacity != 100) {
         qtcX11SetOpacity(wid, opacity);
-
+    }
     prop |= (((toQtColor(bgnd->red) & 0xFF) << 24) |
              ((toQtColor(bgnd->green) & 0xFF) << 16) |
              ((toQtColor(bgnd->blue) & 0xFF) << 8));
-    qtcX11CallVoid(change_property, XCB_PROP_MODE_REPLACE, wid,
-                   qtc_x11_atoms[QTC_X11_ATOM_QTC_BGND], XCB_ATOM_CARDINAL,
-                   32, 1, (unsigned char*)&prop);
+    qtcX11ChangeProperty(XCB_PROP_MODE_REPLACE, wid, qtc_x11_qtc_bgnd,
+                         XCB_ATOM_CARDINAL, 32, 1, &prop);
     qtcX11Flush();
 }
 
 static gboolean
-qtcWindowKeyRelease(GtkWidget *widget, GdkEventKey *event, gpointer user_data)
+qtcWindowKeyRelease(GtkWidget *widget, GdkEventKey *event, void *user_data)
 {
     QTC_UNUSED(user_data);
     // Ensure only ctrl/alt/shift/capsLock are pressed...
     if (GDK_CONTROL_MASK & event->state && GDK_MOD1_MASK & event->state &&
         !event->is_modifier && 0 == (event->state & 0xFF00)) {
-        gboolean toggled = FALSE;
+        bool toggled = false;
         if (opts.menubarHiding & HIDE_KEYBOARD &&
-            (QTC_KEY_m == event->keyval || QTC_KEY_M == event->keyval)) {
+            (GDK_KEY_m == event->keyval || GDK_KEY_M == event->keyval)) {
             toggled = qtcWindowToggleMenuBar(widget);
         }
         if (opts.statusbarHiding & HIDE_KEYBOARD &&
-            (QTC_KEY_s == event->keyval || QTC_KEY_S == event->keyval)) {
+            (GDK_KEY_s == event->keyval || GDK_KEY_S == event->keyval)) {
             toggled = qtcWindowToggleStatusBar(widget);
         }
         if (toggled) {
             gtk_widget_queue_draw(widget);
         }
     }
-    return FALSE;
+    return false;
 }
 
 static gboolean
-qtcWindowMap(GtkWidget *widget, GdkEventKey *event, gpointer user_data)
+qtcWindowMap(GtkWidget *widget, GdkEventKey *event, void *user_data)
 {
     QTC_UNUSED(event);
     QTC_UNUSED(user_data);
-    int opacity = GPOINTER_TO_INT(
-        g_object_get_data(G_OBJECT(widget), "QTC_WINDOW_OPACITY"));
-    qtcWindowSetProperties(widget, (unsigned short)opacity);
+    QTC_DEF_WIDGET_PROPS(props, widget);
+    qtcWindowSetProperties(widget, qtcWidgetProps(props)->windowOpacity);
 
-    if(opts.menubarHiding&HIDE_KWIN)
-    {
-        GtkWidget *menuBar=qtcWindowGetMenuBar(widget, 0);
+    if (opts.menubarHiding & HIDE_KWIN) {
+        GtkWidget *menuBar = qtcWindowGetMenuBar(widget, 0);
 
-        if(menuBar)
-        {
-            int size=gtk_widget_get_visible(menuBar) ? qtcWidgetGetAllocation(menuBar).height : 0;
+        if (menuBar) {
+            int size = (gtk_widget_get_visible(menuBar) ?
+                        qtcWidgetGetAllocation(menuBar).height : 0);
 
             qtcMenuEmitSize(menuBar, size);
             qtcWindowMenuBarDBus(widget, size);
@@ -508,50 +506,47 @@ qtcWindowMap(GtkWidget *widget, GdkEventKey *event, gpointer user_data)
         if(statusBar)
             qtcWindowStatusBarDBus(widget, !gtk_widget_get_visible(statusBar));
     }
-    return FALSE;
+    return false;
 }
 
 gboolean
 qtcWindowSetup(GtkWidget *widget, int opacity)
 {
-    GObject *obj = NULL;
-    if (widget && (obj = G_OBJECT(widget)) &&
-        !g_object_get_data(obj, "QTC_WINDOW_HACK_SET")) {
-        g_object_set_data(obj, "QTC_WINDOW_HACK_SET", (gpointer)1);
-        if (!(IS_FLAT_BGND(opts.bgndAppearance)) ||
-            IMG_NONE != opts.bgndImage.type) {
-            QtCWindow *window = qtcWindowLookupHash(widget, TRUE);
+    QTC_DEF_WIDGET_PROPS(props, widget);
+    if (widget && !qtcWidgetProps(props)->windowHacked) {
+        qtcWidgetProps(props)->windowHacked = true;
+        if (!qtcIsFlatBgnd(opts.bgndAppearance) ||
+            opts.bgndImage.type != IMG_NONE) {
+            QtCWindow *window = qtcWindowLookupHash(widget, true);
             if (window) {
-                GtkAllocation alloc = qtcWidgetGetAllocation(widget);
-                qtcConnectToData(obj, "QTC_WINDOW_CONFIGURE_ID",
-                                 "configure-event", qtcWindowConfigure, window);
+                QtcRect alloc = qtcWidgetGetAllocation(widget);
+                qtcConnectToProp(props, windowConfigure, "configure-event",
+                                 qtcWindowConfigure, window);
                 window->width = alloc.width;
                 window->height = alloc.height;
                 window->widget = widget;
             }
         }
-        qtcConnectToData(obj, "QTC_WINDOW_DESTROY_ID", "destroy-event",
+        qtcConnectToProp(props, windowDestroy, "destroy-event",
                          qtcWindowDestroy, NULL);
-        qtcConnectToData(obj, "QTC_WINDOW_STYLE_SET_ID", "style-set",
+        qtcConnectToProp(props, windowStyleSet, "style-set",
                          qtcWindowStyleSet, NULL);
         if ((opts.menubarHiding & HIDE_KEYBOARD) ||
-            (opts.statusbarHiding & HIDE_KEYBOARD))
-            qtcConnectToData(obj, "QTC_WINDOW_KEY_RELEASE_ID",
-                             "key-release-event", qtcWindowKeyRelease, NULL);
-        g_object_set_data(G_OBJECT(widget), "QTC_WINDOW_OPACITY",
-                          GINT_TO_POINTER(opacity));
+            (opts.statusbarHiding & HIDE_KEYBOARD)) {
+            qtcConnectToProp(props, windowKeyRelease, "key-release-event",
+                             qtcWindowKeyRelease, NULL);
+        }
+        qtcWidgetProps(props)->windowOpacity = (unsigned short)opacity;
         qtcWindowSetProperties(widget, (unsigned short)opacity);
 
         if ((opts.menubarHiding & HIDE_KWIN) ||
             (opts.statusbarHiding & HIDE_KWIN) || 100 != opacity)
-            qtcConnectToData(obj, "QTC_WINDOW_MAP_ID", "map-event",
-                             qtcWindowMap, NULL);
+            qtcConnectToProp(props, windowMap, "map-event", qtcWindowMap, NULL);
         if (opts.shadeMenubarOnlyWhenActive || BLEND_TITLEBAR ||
             opts.menubarHiding || opts.statusbarHiding)
-            qtcConnectToData(obj, "QTC_WINDOW_CLIENT_EVENT_ID", "client-event",
+            qtcConnectToProp(props, windowClientEvent, "client-event",
                              qtcWindowClientEvent, NULL);
-        return TRUE;
+        return true;
     }
-
-    return FALSE;
+    return false;
 }
