@@ -1,22 +1,24 @@
-/*
-  QtCurve (C) Craig Drummond, 2003 - 2010 craig.p.drummond@gmail.com
-
-  ----
-
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public
-  License version 2 as published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; see the file COPYING.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
- */
+/*****************************************************************************
+ *   Copyright 2003 - 2010 Craig Drummond <craig.p.drummond@gmail.com>       *
+ *   Copyright 2013 - 2014 Yichao Yu <yyc1992@gmail.com>                     *
+ *                                                                           *
+ *   This program is free software; you can redistribute it and/or modify    *
+ *   it under the terms of the GNU Lesser General Public License as          *
+ *   published by the Free Software Foundation; either version 2.1 of the    *
+ *   License, or (at your option) version 3, or any later version accepted   *
+ *   by the membership of KDE e.V. (or its successor approved by the         *
+ *   membership of KDE e.V.), which shall act as a proxy defined in          *
+ *   Section 6 of version 3 of the license.                                  *
+ *                                                                           *
+ *   This program is distributed in the hope that it will be useful,         *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of          *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       *
+ *   Lesser General Public License for more details.                         *
+ *                                                                           *
+ *   You should have received a copy of the GNU Lesser General Public        *
+ *   License along with this library. If not,                                *
+ *   see <http://www.gnu.org/licenses/>.                                     *
+ *****************************************************************************/
 
 #include <qtcurve-utils/dirs.h>
 #include "common.h"
@@ -53,7 +55,7 @@ static int c2h(char ch)
 #define ATOH(str) ((c2h(*str)<<4)+c2h(*(str+1)))
 
 void
-qtcSetRgb(color *col, const char *str)
+qtcSetRgb(QColor *col, const char *str)
 {
     if (str && strlen(str) > 6) {
         int offset = '#' == str[0] ? 1 : 0;
@@ -199,7 +201,9 @@ static EAppearance toAppearance(const char *str, EAppearance def, EAppAllow allo
     return def;
 }
 
-static EShade toShade(const char *str, bool allowMenu, EShade def, bool menuShade, color *col)
+static EShade
+toShade(const char *str, bool allowMenu, EShade def,
+        bool menuShade, QColor *col)
 {
     if(str && 0!=str[0])
     {
@@ -437,9 +441,8 @@ static bool toLvLines(const char *str, bool def)
 
 static EGradientBorder toGradientBorder(const char *str, bool *haveAlpha)
 {
-    if(str && 0!=str[0])
-    {
-        *haveAlpha=strstr(str, "-alpha") ? true : false;
+    if (str && str[0]) {
+        *haveAlpha = strstr(str, "-alpha") ? true : false;
         if(0==memcmp(str, "light", 5) || 0==memcmp(str, "true", 4))
             return GB_LIGHT;
         if(0==memcmp(str, "none", 4))
@@ -602,9 +605,10 @@ void qtcLoadBgndImage(QtCImage *img)
     }
 }
 
-#endif // (!defined QT_VERSION || QT_VERSION >= 0x040000) && !defined CONFIG_DIALOG
+#endif
 
-static void checkColor(EShade *s, color *c)
+static void
+checkColor(EShade *s, QColor *c)
 {
     if(SHADE_CUSTOM==*s && IS_BLACK(*c))
         *s=SHADE_NONE;
@@ -679,25 +683,24 @@ static void readDoubleList(QtCConfig &cfg, const char *key, double *list, int co
     QStringList strings(readStringEntry(cfg, key).split(',', QString::SkipEmptyParts));
     bool ok(count==strings.size());
 
-    if(ok)
-    {
+    if (ok) {
         QStringList::ConstIterator it(strings.begin());
-        int                        i;
-
-        for(i=0; i<count && ok; ++i, ++it)
+        for (int i = 0;i < count && ok;++i, ++it) {
             list[i]=(*it).toDouble(&ok);
+        }
     }
 
-    if(!ok && strings.size())
-        list[0]=0;
+    if (!ok && strings.size()) {
+        list[0] = 0;
+    }
 }
 
 #define CFG_READ_COLOR(ENTRY) do {                      \
         QString sVal(cfg.readEntry(#ENTRY));            \
         if (sVal.isEmpty()) {                           \
-            opts->ENTRY=def->ENTRY;                     \
+            opts->ENTRY = def->ENTRY;                   \
         } else {                                        \
-            qtcSetRgb(&(opts->ENTRY), TO_LATIN1(sVal)); \
+            qtcSetRgb(&opts->ENTRY, TO_LATIN1(sVal));   \
         }                                               \
     } while (0)
 
@@ -709,7 +712,7 @@ static void readDoubleList(QtCConfig &cfg, const char *key, double *list, int co
         opts->ENTRY.width = opts->ENTRY.height = 0;                     \
         opts->ENTRY.onBorder = false;                                   \
         opts->ENTRY.pos = PP_TR;                                        \
-        if (IMG_FILE == opts->ENTRY.type) {                             \
+        if (opts->ENTRY.type == IMG_FILE) {                             \
             QString file(cfg.readEntry(#ENTRY ".file"));                \
             if (!file.isEmpty()) {                                      \
                 opts->ENTRY.pixmap.file = file;                         \
@@ -720,7 +723,7 @@ static void readDoubleList(QtCConfig &cfg, const char *key, double *list, int co
                 opts->ENTRY.pos = (EPixPos)readNumEntry(cfg, #ENTRY ".pos", \
                                                         (int)PP_TR);    \
             } else {                                                    \
-                opts->ENTRY.type=IMG_NONE;                              \
+                opts->ENTRY.type = IMG_NONE;                            \
             }                                                           \
         }                                                               \
     } while (0)
@@ -1090,28 +1093,21 @@ void qtcCheckConfig(Options *opts)
 
 bool qtcReadConfig(const QString &file, Options *opts, Options *defOpts, bool checkImages)
 {
-    if(file.isEmpty())
-    {
-        const char *env=getenv("QTCURVE_CONFIG_FILE");
+    if (file.isEmpty()) {
+        const char *env = getenv("QTCURVE_CONFIG_FILE");
 
-        if(NULL!=env)
+        if (env)
             return qtcReadConfig(env, opts, defOpts);
-        else
-        {
-            const char *cfgDir=qtcConfDir();
 
-            if(cfgDir)
-            {
-                QString filename(QFile::decodeName(cfgDir)+CONFIG_FILE);
+        const char *cfgDir = qtcConfDir();
+        if (cfgDir) {
+            QString filename(QFile::decodeName(cfgDir)+CONFIG_FILE);
 
-                if(!QFile::exists(filename))
-                    filename=QFile::decodeName(cfgDir) + "../" OLD_CONFIG_FILE;
-                return qtcReadConfig(filename, opts, defOpts);
-            }
+            if (!QFile::exists(filename))
+                filename = QFile::decodeName(cfgDir) + "../" OLD_CONFIG_FILE;
+            return qtcReadConfig(filename, opts, defOpts);
         }
-    }
-    else
-    {
+    } else {
         QtCConfig cfg(file);
 
         if(cfg.ok())
@@ -1220,20 +1216,16 @@ bool qtcReadConfig(const QString &file, Options *opts, Options *defOpts, bool ch
                 CFG_READ_EFFECT(tbarBtnEffect);
             }
             CFG_READ_APPEARANCE_PIXMAP(bgndAppearance, APP_ALLOW_STRIPED,
-                                       &(opts->bgndPixmap), checkImages);
+                                       &opts->bgndPixmap, checkImages);
             CFG_READ_GRAD_TYPE(bgndGrad);
             CFG_READ_GRAD_TYPE(menuBgndGrad);
             CFG_READ_INT_BOOL(lighterPopupMenuBgnd, def->lighterPopupMenuBgnd);
             CFG_READ_APPEARANCE_PIXMAP(menuBgndAppearance, APP_ALLOW_STRIPED,
-                                       &(opts->menuBgndPixmap), checkImages);
+                                       &opts->menuBgndPixmap, checkImages);
 
             if(APPEARANCE_FLAT==opts->menuBgndAppearance && 0==opts->lighterPopupMenuBgnd && opts->version<qtcMakeVersion(1, 7))
                 opts->menuBgndAppearance=APPEARANCE_RAISED;
 
-#ifdef QTC_QT4_ENABLE_PARENTLESS_DIALOG_FIX_SUPPORT
-            CFG_READ_BOOL(fixParentlessDialogs);
-            CFG_READ_STRING_LIST(noDlgFixApps);
-#endif
             CFG_READ_STRIPE(stripedProgress);
             CFG_READ_SLIDER(sliderStyle);
             CFG_READ_BOOL(animatedProgress);
@@ -1403,8 +1395,7 @@ bool qtcReadConfig(const QString &file, Options *opts, Options *defOpts, bool ch
                     QStringList::ConstIterator it(cols.begin()),
                                                end(cols.end());
 
-                    for(int i=0; it!=end; ++it, ++i)
-                    {
+                    for (int i = 0;it != end;++it, ++i) {
                         QColor col;
                         qtcSetRgb(&col, TO_LATIN1((*it)));
                         opts->titlebarButtonColors[i]=col;
@@ -1492,10 +1483,10 @@ void qtcDefaultSettings(Options *opts)
 {
     /* Set hard-coded defaults... */
     // Setup titlebar gradients...
-    qtcSetupGradient(&(opts->customGradient[APPEARANCE_CUSTOM1]), GB_3D,
-                     3,0.0,1.2,0.5,1.0,1.0,1.0);
-    qtcSetupGradient(&(opts->customGradient[APPEARANCE_CUSTOM2]), GB_3D,
-                     3,0.0,0.9,0.5,1.0,1.0,1.0);
+    qtcSetupGradient(&opts->customGradient[APPEARANCE_CUSTOM1], GB_3D, 3,
+                     0.0, 1.2, 0.5, 1.0, 1.0, 1.0);
+    qtcSetupGradient(&opts->customGradient[APPEARANCE_CUSTOM2], GB_3D, 3,
+                     0.0, 0.9, 0.5, 1.0, 1.0, 1.0);
     opts->customShades[0]=1.16;
     opts->customShades[1]=1.07;
     opts->customShades[2]=0.9;
@@ -1571,10 +1562,6 @@ void qtcDefaultSettings(Options *opts)
     opts->toolbarBorders=TB_NONE;
     opts->toolbarSeparators=LINE_SUNKEN;
     opts->splitters=LINE_1DOT;
-#ifdef QTC_QT4_ENABLE_PARENTLESS_DIALOG_FIX_SUPPORT
-    opts->fixParentlessDialogs=false;
-    opts->noDlgFixApps << "kate" << "plasma" << "plasma-desktop" << "plasma-netbook";
-#endif
     opts->customMenuTextColor=false;
     opts->coloredMouseOver=MO_GLOW;
     opts->menubarMouseOver=true;
@@ -1657,11 +1644,12 @@ void qtcDefaultSettings(Options *opts)
     opts->centerTabText=false;
     opts->xbar=false;
     opts->dwtSettings=DWT_BUTTONS_AS_PER_TITLEBAR|DWT_ROUND_TOP_ONLY;
-    opts->menubarApps << "amarok" << "arora" << "kaffeine" << "kcalc" << "smplayer" << "VirtualBox";
+    opts->menubarApps << "smplayer" << "VirtualBox";
     opts->statusbarApps << "kde";
-    opts->useQtFileDialogApps << "googleearth-bin";
-    opts->noMenuBgndOpacityApps << "inkscape" << "sonata" << "totem" << "vmware" << "vmplayer" << "gtk";
-    opts->noBgndOpacityApps << "smplayer" << "kaffeine" << "dragon" << "kscreenlocker" << "inkscape" << "sonata" << "totem" << "vmware" << "vmplayer";
+    opts->noMenuBgndOpacityApps << "sonata" << "totem" << "vmware"
+                                << "vmplayer" << "gtk";
+    opts->noBgndOpacityApps << "smplayer" << "sonata" << "totem" << "vmware"
+                            << "vmplayer";
     opts->noMenuStripeApps << "gtk" << "soffice.bin";
 
 #if defined CONFIG_DIALOG
@@ -1687,26 +1675,26 @@ void qtcDefaultSettings(Options *opts)
 #include <KDE/KConfig>
 #include <KDE/KConfigGroup>
 
-static const char *toStr(EDefBtnIndicator ind)
+static const char*
+toStr(EDefBtnIndicator ind)
 {
-    switch(ind)
-    {
-        case IND_NONE:
-            return "none";
-        case IND_FONT_COLOR:
-            return "fontcolor";
-        case IND_CORNER:
-            return "corner";
-        case IND_TINT:
-            return "tint";
-        case IND_GLOW:
-            return "glow";
-        case IND_DARKEN:
-            return "darken";
-        case IND_SELECTED:
-            return "origselected";
-        default:
-            return "colored";
+    switch(ind) {
+    case IND_NONE:
+        return "none";
+    case IND_FONT_COLOR:
+        return "fontcolor";
+    case IND_CORNER:
+        return "corner";
+    case IND_TINT:
+        return "tint";
+    case IND_GLOW:
+        return "glow";
+    case IND_DARKEN:
+        return "darken";
+    case IND_SELECTED:
+        return "origselected";
+    default:
+        return "colored";
     }
 }
 
@@ -2248,10 +2236,6 @@ bool qtcWriteConfig(KConfig *cfg, const Options &opts, const Options &def, bool
         CFG_WRITE_ENTRY(bgndGrad)
         CFG_WRITE_ENTRY(menuBgndGrad)
         CFG_WRITE_APPEARANCE_ENTRY_PIXMAP(menuBgndAppearance, APP_ALLOW_STRIPED, menuBgndPixmap)
-#ifdef QTC_QT4_ENABLE_PARENTLESS_DIALOG_FIX_SUPPORT
-        CFG_WRITE_ENTRY(fixParentlessDialogs)
-        CFG_WRITE_STRING_LIST_ENTRY(noDlgFixApps)
-#endif
         CFG_WRITE_ENTRY(stripedProgress)
         CFG_WRITE_ENTRY(sliderStyle)
         CFG_WRITE_ENTRY(animatedProgress)
