@@ -1,26 +1,28 @@
+/*****************************************************************************
+ *   Copyright 2007 - 2010 Craig Drummond <craig.p.drummond@gmail.com>       *
+ *   Copyright 2013 - 2014 Yichao Yu <yyc1992@gmail.com>                     *
+ *                                                                           *
+ *   This program is free software; you can redistribute it and/or modify    *
+ *   it under the terms of the GNU Lesser General Public License as          *
+ *   published by the Free Software Foundation; either version 2.1 of the    *
+ *   License, or (at your option) version 3, or any later version accepted   *
+ *   by the membership of KDE e.V. (or its successor approved by the         *
+ *   membership of KDE e.V.), which shall act as a proxy defined in          *
+ *   Section 6 of version 3 of the license.                                  *
+ *                                                                           *
+ *   This program is distributed in the hope that it will be useful,         *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of          *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       *
+ *   Lesser General Public License for more details.                         *
+ *                                                                           *
+ *   You should have received a copy of the GNU Lesser General Public        *
+ *   License along with this library. If not,                                *
+ *   see <http://www.gnu.org/licenses/>.                                     *
+ *****************************************************************************/
+
 #ifndef __QTCURVE_H__
 #define __QTCURVE_H__
 
-/*
-  QtCurve (C) Craig Drummond, 2007 - 2010 craig.p.drummond@gmail.com
-
-  ----
-
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public
-  License version 2 as published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; see the file COPYING.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
-*/
-
 #include <QTime>
 #include <QPalette>
 #include <QMap>
@@ -29,27 +31,22 @@
 #include <QCache>
 #include <QColor>
 #include <QStyleOption>
-#include <Q_UINT64>
+#include <QtGlobal>
+#include <QCommonStyle>
 typedef qulonglong QtcKey;
 #include <common/common.h>
 
-#ifdef QTC_QT4_ENABLE_KDE
-#include <KDE/KComponentData>
-#endif
+// TODO maybe we should have QTC_QT4_DBUS_FOUND?
+#include <QDBusInterface>
 
-// #ifdef QTC_KSTYLE
-// #include <kstyle.h>
-// #define BASE_STYLE KStyle
-// #else
-#include <QCommonStyle>
-#define BASE_STYLE QCommonStyle
-// #endif
+#ifdef QTC_QT4_ENABLE_KDE
+#  include <KDE/KComponentData>
+#endif
 
 class QStyleOptionSlider;
 class QLabel;
 class QMenuBar;
 class QScrollBar;
-class QDBusInterface;
 class QMainWindow;
 class QStatusBar;
 class QAbstractScrollArea;
@@ -60,14 +57,11 @@ namespace QtCurve {
 class WindowManager;
 class BlurHelper;
 class ShortcutHandler;
-#ifdef QTC_ENABLE_X11
 class ShadowHelper;
-#endif
 
 class Style: public QCommonStyle {
     Q_OBJECT
     Q_CLASSINFO("X-KDE-CustomElements", "true")
-
 public:
     enum BackgroundType {
         BGND_WINDOW,
@@ -125,64 +119,72 @@ public:
 #endif
     ~Style();
 
+    virtual void polish(QApplication *app) override;
+    virtual void polish(QPalette &palette) override;
+    virtual void polish(QWidget *widget) override;
+    virtual void unpolish(QApplication *app) override;
+    virtual void unpolish(QWidget *widget) override;
+
+    virtual bool eventFilter(QObject *object, QEvent *event) override;
+    virtual void timerEvent(QTimerEvent *event) override;
+
+    virtual int pixelMetric(PixelMetric metric, const QStyleOption *option=0,
+                            const QWidget *widget=0) const override;
+    virtual int styleHint(StyleHint hint, const QStyleOption *option,
+                          const QWidget *widget,
+                          QStyleHintReturn *returnData=0) const override;
+    virtual QSize sizeFromContents(ContentsType type,
+                                   const QStyleOption *option,
+                                   const QSize &size,
+                                   const QWidget *widget) const override;
+    virtual QPalette standardPalette() const override;
+
+    virtual void drawPrimitive(PrimitiveElement element,
+                               const QStyleOption *option,
+                               QPainter *painter,
+                               const QWidget *widget) const override;
+    virtual void drawControl(ControlElement control, const QStyleOption *option,
+                             QPainter *painter,
+                             const QWidget *widget) const override;
+    virtual void drawComplexControl(ComplexControl control,
+                                    const QStyleOptionComplex *option,
+                                    QPainter *painter,
+                                    const QWidget *widget) const override;
+    virtual void drawItemText(QPainter *painter, const QRect &rect, int flags,
+                              const QPalette &pal, bool enabled,
+                              const QString &text, QPalette::ColorRole textRole=
+                              QPalette::NoRole) const override;
+
+    virtual QRect subElementRect(SubElement element, const QStyleOption *option,
+                                 const QWidget *widget) const override;
+    virtual QRect subControlRect(ComplexControl control,
+                                 const QStyleOptionComplex *option,
+                                 SubControl subControl,
+                                 const QWidget *widget) const override;
+    virtual SubControl hitTestComplexControl(ComplexControl control,
+                                             const QStyleOptionComplex *option,
+                                             const QPoint &pos,
+                                             const QWidget *widget) const override;
+    void prePolish(QWidget *w) const;
+    void
+    prePolish(const QWidget *w) const
+    {
+        prePolish(const_cast<QWidget*>(w));
+    }
+
+private:
     void init(bool initial);
     void freeColor(QSet<QColor*> &freedColors, QColor **cols);
     void freeColors();
-
-    Options&
-    options()
-    {
-        return opts;
-    }
-
-    void polish(QApplication *app);
-    void polish(QPalette &palette);
-    void polish(QWidget *widget);
-
-#if (QT_VERSION >= QT_VERSION_CHECK(4, 4, 0))
     void polishFormLayout(QFormLayout *layout);
     void polishLayout(QLayout *layout);
-#endif
     void polishScrollArea(QAbstractScrollArea *scrollArea,
                           bool isKFilePlacesView=false) const;
 
-    void unpolish(QApplication *app);
-    void unpolish(QWidget *widget);
-    bool eventFilter(QObject *object, QEvent *event);
-    void timerEvent(QTimerEvent *event);
-    int pixelMetric(PixelMetric metric, const QStyleOption *option=0,
-                    const QWidget *widget=0) const;
-    int styleHint(StyleHint hint, const QStyleOption *option,
-                  const QWidget *widget, QStyleHintReturn *returnData=0) const;
-    QPalette standardPalette() const;
-    void drawPrimitive(PrimitiveElement element, const QStyleOption *option,
-                       QPainter *painter, const QWidget *widget) const;
-    void drawControl(ControlElement control, const QStyleOption *option,
-                     QPainter *painter, const QWidget *widget) const;
-    void drawComplexControl(ComplexControl control,
-                            const QStyleOptionComplex *option,
-                            QPainter *painter, const QWidget *widget) const;
     void drawItemTextWithRole(QPainter *painter, const QRect &rect, int flags,
                               const QPalette &pal, bool enabled,
                               const QString &text,
                               QPalette::ColorRole textRole) const;
-    void drawItemText(QPainter *painter, const QRect &rect, int flags,
-                      const QPalette &pal, bool enabled, const QString &text,
-                      QPalette::ColorRole textRole=QPalette::NoRole) const;
-    QSize sizeFromContents(ContentsType type, const QStyleOption *option,
-                           const QSize &size, const QWidget *widget) const;
-    QRect subElementRect(SubElement element, const QStyleOption *option,
-                         const QWidget *widget) const;
-    QRect subControlRect(ComplexControl control,
-                         const QStyleOptionComplex *option,
-                         SubControl subControl, const QWidget *widget) const;
-    SubControl hitTestComplexControl(ComplexControl control,
-                                     const QStyleOptionComplex *option,
-                                     const QPoint &pos,
-                                     const QWidget *widget) const;
-
-private:
-
     void drawSideBarButton(QPainter *painter, const QRect &r,
                            const QStyleOption *option,
                            const QWidget *widget) const;
@@ -199,29 +201,28 @@ private:
                                    EAppearance bevApp,
                                    const QColor *cols) const;
     void drawBevelGradient(const QColor &base, QPainter *p, QRect const &r,
-                           const QPainterPath &path,
-                           bool horiz, bool sel, EAppearance bevApp,
-                           EWidget w=WIDGET_OTHER, bool useCache=true) const;
+                           const QPainterPath &path, bool horiz, bool sel,
+                           EAppearance bevApp, EWidget w=WIDGET_OTHER,
+                           bool useCache=true) const;
     void drawBevelGradientReal(const QColor &base, QPainter *p, const QRect &r,
-                               const QPainterPath &path,
-                               bool horiz, bool sel, EAppearance bevApp,
-                               EWidget w) const;
+                               const QPainterPath &path, bool horiz, bool sel,
+                               EAppearance bevApp, EWidget w) const;
 
     void
     drawBevelGradient(const QColor &base, QPainter *p, QRect const &r,
                       bool horiz, bool sel, EAppearance bevApp,
                       EWidget w=WIDGET_OTHER, bool useCache=true) const
     {
-        drawBevelGradient(base, p, r,
-                          QPainterPath(), horiz, sel, bevApp, w, useCache);
+        drawBevelGradient(base, p, r, QPainterPath(), horiz, sel, bevApp, w,
+                          useCache);
     }
     void
     drawBevelGradientReal(const QColor &base, QPainter *p, const QRect &r,
                           bool horiz, bool sel,
                           EAppearance bevApp, EWidget w) const
     {
-        drawBevelGradientReal(base, p, r, QPainterPath(), horiz, sel, bevApp,
-                              w);
+        drawBevelGradientReal(base, p, r, QPainterPath(), horiz,
+                              sel, bevApp, w);
     }
 
     void drawSunkenBevel(QPainter *p, const QRect &r, const QColor &col) const;
@@ -237,10 +238,10 @@ private:
                             bool onToolbar) const;
     void drawGlow(QPainter *p, const QRect &r, EWidget w,
                   const QColor *cols=0L) const;
-    void drawEtch(QPainter *p, const QRect &r, const QWidget *widget, EWidget w,
-                  bool raised=false, int round=ROUNDED_ALL) const;
-    void drawBgndRing(QPainter &painter, int x, int y, int size, int size2,
-                      bool isWindow) const;
+    void drawEtch(QPainter *p, const QRect &r, const QWidget *widget,
+                  EWidget w, bool raised=false, int round=ROUNDED_ALL) const;
+    void drawBgndRing(QPainter &painter, int x, int y, int size,
+                      int size2, bool isWindow) const;
     QPixmap drawStripes(const QColor &color, int opacity) const;
     void drawBackground(QPainter *p, const QColor &bgnd, const QRect &r,
                         int opacity, BackgroundType type, EAppearance app,
@@ -248,10 +249,10 @@ private:
     void drawBackgroundImage(QPainter *p, bool isWindow, const QRect &r) const;
     void drawBackground(QPainter *p, const QWidget *widget,
                         BackgroundType type) const;
-    QPainterPath buildPath(const QRectF &r, EWidget w, int round,
-                           double radius) const;
-    QPainterPath buildPath(const QRect &r, EWidget w, int round,
-                           double radius) const;
+    QPainterPath buildPath(const QRectF &r, EWidget w,
+                           int round, double radius) const;
+    QPainterPath buildPath(const QRect &r, EWidget w,
+                           int round, double radius) const;
     void buildSplitPath(const QRect &r, int round, double radius,
                         QPainterPath &tl, QPainterPath &br) const;
     void drawBorder(QPainter *p, const QRect &r, const QStyleOption *option,
@@ -270,9 +271,8 @@ private:
     bool drawMdiButton(QPainter *painter, const QRect &r, bool hover,
                        bool sunken, const QColor *cols) const;
     void drawMdiIcon(QPainter *painter, const QColor &color, const QColor &bgnd,
-                     const QRect &r,
-                     bool hover, bool sunken, Icon iclearcon, bool stdSize,
-                     bool drewFrame) const;
+                     const QRect &r, bool hover, bool sunken, Icon iclearcon,
+                     bool stdSize, bool drewFrame) const;
     void drawIcon(QPainter *painter, const QColor &color, const QRect &r,
                   bool sunken, Icon icon, bool stdSize=true) const;
     void drawEntryField(QPainter *p, const QRect &rx, const QWidget *widget,
@@ -292,19 +292,17 @@ private:
     void drawSliderGroove(QPainter *p, const QRect &groove, const QRect &handle,
                           const QStyleOptionSlider *slider,
                           const QWidget *widget) const;
-    int  getOpacity(const QWidget *widget, QPainter *p) const;
     void drawMenuOrToolBarBackground(const QWidget *widget, QPainter *p,
                                      const QRect &r, const QStyleOption *option,
-                                     bool menu=true,
-                                     bool horiz=true) const;
+                                     bool menu=true, bool horiz=true) const;
     void drawHandleMarkers(QPainter *p, const QRect &r,
                            const QStyleOption *option, bool tb,
                            ELine handles) const;
     void fillTab(QPainter *p, const QRect &r, const QStyleOption *option,
                  const QColor &fill, bool horiz, EWidget tab,
                  bool tabOnly) const;
-    void colorTab(QPainter *p, const QRect &r, bool horiz, EWidget tab,
-                  int round) const;
+    void colorTab(QPainter *p, const QRect &r, bool horiz,
+                  EWidget tab, int round) const;
     void shadeColors(const QColor &base, QColor *vals) const;
     const QColor *buttonColors(const QStyleOption *option) const;
     QColor titlebarIconColor(const QStyleOption *option) const;
@@ -315,8 +313,9 @@ private:
     const QColor*
     backgroundColors(const QStyleOption *option) const
     {
-        return option ? backgroundColors(option->palette.background().color()) :
-            itsBackgroundCols;
+        return (option ?
+                backgroundColors(option->palette.background().color()) :
+                m_backgroundCols);
     }
     const QColor *highlightColors(const QColor &col) const;
     const QColor*
@@ -344,22 +343,19 @@ private:
     QPixmap *getPixmap(const QColor col, EPixmap p, double shade=1.0) const;
     const QColor &checkRadioCol(const QStyleOption *opt) const;
     QColor shade(const QColor &a, double k) const;
-    void shade(const color &ca, color *cb, double k) const;
+    void shade(const QColor &ca, QColor *cb, double k) const;
     QColor getLowerEtchCol(const QWidget *widget) const;
     int getFrameRound(const QWidget *widget) const;
-    void unregisterArgbWidget(QWidget *w);
 
 private Q_SLOTS:
-
     void widgetDestroyed(QObject *o);
-    QIcon standardIconImplementation(StandardPixmap pix,
-                                     const QStyleOption *option=0,
-                                     const QWidget *widget=0) const;
-    int layoutSpacingImplementation(QSizePolicy::ControlType control1,
-                                    QSizePolicy::ControlType control2,
-                                    Qt::Orientation orientation,
-                                    const QStyleOption *option,
-                                    const QWidget *widget) const;
+    int layoutSpacingImplementation(
+        QSizePolicy::ControlType control1, QSizePolicy::ControlType control2,
+        Qt::Orientation orientation, const QStyleOption *option=0,
+        const QWidget *widget=0) const;
+    QIcon standardIconImplementation(
+        StandardPixmap pix, const QStyleOption *option=0,
+        const QWidget *widget=0) const;
     void kdeGlobalSettingsChange(int type, int);
     void borderSizesChanged();
     void toggleMenuBar(unsigned int xid);
@@ -375,76 +371,94 @@ private:
     void setDecorationColors();
     void applyKdeSettings(bool pal);
 #endif
-#ifdef QTC_ENABLE_X11
     bool isWindowDragWidget(QObject *o);
     void emitMenuSize(QWidget *w, unsigned short size, bool force=false);
     void emitStatusBarState(QStatusBar *sb);
-#endif
+    const QColor&
+    MOArrow(QFlags<State> state, const QPalette &palette, bool mo,
+            QPalette::ColorRole rol) const
+    {
+        if (!(state & State_Enabled)) {
+            return palette.color(QPalette::Disabled, rol);
+        } else if (opts.coloredMouseOver != MO_NONE && mo) {
+            return m_mouseOverCols[ARROW_MO_SHADE];
+        } else {
+            return palette.color(rol);
+        }
+    }
+    const QColor&
+    MOArrow(QFlags<State> state, const QPalette &palette,
+            QPalette::ColorRole rol) const
+    {
+        return MOArrow(state, palette, state & State_MouseOver, rol);
+    }
+    QDBusInterface*
+    getKWinDBus()
+    {
+        if (qtcUnlikely(!m_dBus)) {
+            m_dBus = new QDBusInterface("org.kde.kwin", "/QtCurve",
+                                        "org.kde.QtCurve");
+        }
+        return m_dBus;
+    }
 
 private:
-
     mutable Options opts;
-    QColor itsHighlightCols[TOTAL_SHADES + 1],
-        itsBackgroundCols[TOTAL_SHADES + 1],
-        itsMenubarCols[TOTAL_SHADES + 1],
-        itsFocusCols[TOTAL_SHADES + 1],
-        itsMouseOverCols[TOTAL_SHADES + 1],
-        *itsPopupMenuCols,
-        *itsSliderCols,
-        *itsDefBtnCols,
-        *itsComboBtnCols,
-        *itsCheckRadioSelCols,
-        *itsSortedLvColors,
-        *itsOOMenuCols,
-        *itsProgressCols,
-        itsButtonCols[TOTAL_SHADES + 1],
-        itsCheckRadioCol;
-    bool itsSaveMenuBarStatus,
-        itsSaveStatusBarStatus,
-        itsUsePixmapCache,
-        itsInactiveChangeSelectionColor;
-    PreviewType itsIsPreview;
-    mutable QColor *itsSidebarButtonsCols;
-    mutable QColor *itsActiveMdiColors;
-    mutable QColor *itsMdiColors;
-    mutable QColor itsActiveMdiTextColor;
-    mutable QColor itsMdiTextColor;
-    mutable QColor itsColoredButtonCols[TOTAL_SHADES + 1];
-    mutable QColor itsColoredBackgroundCols[TOTAL_SHADES + 1];
-    mutable QColor itsColoredHighlightCols[TOTAL_SHADES + 1];
-    mutable QCache<QtcKey, QPixmap> itsPixmapCache;
-    mutable bool itsActive;
-    mutable const QWidget *itsSbWidget;
-    mutable QLabel *itsClickedLabel;
-    QSet<QProgressBar*> itsProgressBars;
-    QSet<QWidget*> itsTransparentWidgets;
-    int itsProgressBarAnimateTimer,
-        itsAnimateStep;
-    QTime itsTimer;
-    mutable QMap<int, QColor*> itsTitleBarButtonsCols;
-#ifdef QTC_QT4_ENABLE_PARENTLESS_DIALOG_FIX_SUPPORT
-    mutable QMap<QWidget*, QWidget*> itsReparentedDialogs;
-#endif
-    mutable QList<int> itsMdiButtons[2]; // 0=left, 1=right
-    mutable int itsTitlebarHeight;
+    QColor m_highlightCols[TOTAL_SHADES + 1],
+        m_backgroundCols[TOTAL_SHADES + 1],
+        m_menubarCols[TOTAL_SHADES + 1],
+        m_focusCols[TOTAL_SHADES + 1],
+        m_mouseOverCols[TOTAL_SHADES + 1],
+        *m_popupMenuCols,
+        *m_sliderCols,
+        *m_defBtnCols,
+        *m_comboBtnCols,
+        *m_checkRadioSelCols,
+        *m_sortedLvColors,
+        *m_ooMenuCols,
+        *m_progressCols,
+        m_buttonCols[TOTAL_SHADES + 1],
+        m_checkRadioCol;
+    bool m_saveMenuBarStatus,
+        m_saveStatusBarStatus,
+        m_usePixmapCache,
+        m_inactiveChangeSelectionColor;
+    PreviewType m_isPreview;
+    mutable QColor *m_sidebarButtonsCols;
+    mutable QColor *m_activeMdiColors;
+    mutable QColor *m_mdiColors;
+    mutable QColor m_activeMdiTextColor;
+    mutable QColor m_mdiTextColor;
+    mutable QColor m_coloredButtonCols[TOTAL_SHADES + 1];
+    mutable QColor m_coloredBackgroundCols[TOTAL_SHADES + 1];
+    mutable QColor m_coloredHighlightCols[TOTAL_SHADES + 1];
+    mutable QCache<QtcKey, QPixmap> m_pixmapCache;
+    mutable bool m_active;
+    mutable const QWidget *m_sbWidget;
+    mutable QLabel *m_clickedLabel;
+    QSet<QProgressBar*> m_progressBars;
+    int m_progressBarAnimateTimer,
+        m_animateStep;
+    QTime m_timer;
+    mutable QMap<int, QColor*> m_titleBarButtonsCols;
+    mutable QList<int> m_mdiButtons[2]; // 0=left, 1=right
+    mutable int m_titlebarHeight;
 
     // Required for Q3Header hover...
-    QPoint itsPos;
-    QWidget *itsHoverWidget;
-#ifdef QTC_ENABLE_X11
-    QDBusInterface *itsDBus;
-    QtCurve::ShadowHelper *itsShadowHelper;
-#endif
-    mutable QScrollBar *itsSViewSBar;
-    mutable QMap<QWidget*, QSet<QWidget*> > itsSViewContainers;
+    QPoint m_pos;
+    QWidget *m_hoverWidget;
+    QDBusInterface *m_dBus;
+    ShadowHelper *m_shadowHelper;
+    mutable QScrollBar *m_sViewSBar;
+    mutable QMap<QWidget*, QSet<QWidget*> > m_sViewContainers;
 #ifdef QTC_QT4_ENABLE_KDE
-    KComponentData itsComponentData;
+    KComponentData m_componentData;
 #endif
-    QtCurve::WindowManager *itsWindowManager;
-    QtCurve::BlurHelper *itsBlurHelper;
-    QtCurve::ShortcutHandler *itsShortcutHandler;
+    WindowManager *m_windowManager;
+    BlurHelper *m_blurHelper;
+    ShortcutHandler *m_shortcutHandler;
 #ifdef QTC_QT4_STYLE_SUPPORT
-    QString itsName;
+    QString m_name;
 #endif
 };
 }
