@@ -1,7 +1,29 @@
+/*****************************************************************************
+ *   Copyright 2010 Craig Drummond <craig.p.drummond@gmail.com>              *
+ *   Copyright 2013 - 2014 Yichao Yu <yyc1992@gmail.com>                     *
+ *                                                                           *
+ *   This program is free software; you can redistribute it and/or modify    *
+ *   it under the terms of the GNU Lesser General Public License as          *
+ *   published by the Free Software Foundation; either version 2.1 of the    *
+ *   License, or (at your option) version 3, or any later version accepted   *
+ *   by the membership of KDE e.V. (or its successor approved by the         *
+ *   membership of KDE e.V.), which shall act as a proxy defined in          *
+ *   Section 6 of version 3 of the license.                                  *
+ *                                                                           *
+ *   This program is distributed in the hope that it will be useful,         *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of          *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       *
+ *   Lesser General Public License for more details.                         *
+ *                                                                           *
+ *   You should have received a copy of the GNU Lesser General Public        *
+ *   License along with this library. If not,                                *
+ *   see <http://www.gnu.org/licenses/>.                                     *
+ *****************************************************************************/
+
 // Copied from oxygenwindowmanager.cpp svnversion: 1139230
 
 //////////////////////////////////////////////////////////////////////////////
-// oxygenwindowmanager.cpp
+// windowmanager.cpp
 // pass some window mouse press/release/move event actions to window manager
 // -------------------
 //
@@ -62,38 +84,29 @@
 #  include <KGlobalSettings>
 #endif
 
-#ifdef QTC_ENABLE_X11
-#  include <qtcurve-utils/x11wmmove.h>
-#endif
+#include <qtcurve-utils/x11wmmove.h>
 
 namespace QtCurve {
-    //_____________________________________________________________
-    WindowManager::WindowManager( QObject* parent ):
-        QObject( parent ),
-        _enabled( true ),
-#ifdef QTC_ENABLE_X11
-        _useWMMoveResize( true ),
-#else
-        _useWMMoveResize( false ),
-#endif
-        _dragMode( WM_DRAG_NONE ),
+WindowManager::WindowManager(QObject *parent):
+    QObject( parent),
+    _enabled(true),
+    _useWMMoveResize(qtcX11Enabled()),
+    _dragMode(WM_DRAG_NONE),
 #ifdef QTC_QT4_ENABLE_KDE
-        _dragDistance(KGlobalSettings::dndEventDelay()),
+    _dragDistance(KGlobalSettings::dndEventDelay()),
 #else
-        _dragDistance(QApplication::startDragDistance()),
+    _dragDistance(QApplication::startDragDistance()),
 #endif
-        _dragDelay( QApplication::startDragTime() ),
-        _dragAboutToStart( false ),
-        _dragInProgress( false ),
-        _locked( false ),
-        _cursorOverride( false )
-    {
-
-        // install application wise event filter
-        _appEventFilter = new AppEventFilter( this );
-        qApp->installEventFilter( _appEventFilter );
-
-    }
+    _dragDelay(QApplication::startDragTime()),
+    _dragAboutToStart(false),
+    _dragInProgress(false),
+    _locked(false),
+    _cursorOverride(false)
+{
+    // install application wise event filter
+    _appEventFilter = new AppEventFilter(this);
+    qApp->installEventFilter(_appEventFilter);
+}
 
     //_____________________________________________________________
     void WindowManager::initialize( int windowDrag, const QStringList &whiteList, const QStringList &blackList )
@@ -113,31 +126,25 @@ namespace QtCurve {
 
     }
 
-    //_____________________________________________________________
     void WindowManager::registerWidget( QWidget* widget )
     {
-
-        if( isBlackListed( widget ) )
-        {
-
+        if (isBlackListed(widget)) {
             /*
             also install filter for blacklisted widgets
             to be able to catch the relevant events and prevent
             the drag to happen
             */
-            Utils::addEventFilter(widget, this);
-
-        } else if( isDragable( widget ) ) {
-            Utils::addEventFilter(widget, this);
+            widget->installEventFilter(this);
+        } else if (isDragable(widget)) {
+            widget->installEventFilter(this);
         }
-
     }
 
-    //_____________________________________________________________
     void WindowManager::unregisterWidget( QWidget* widget )
     {
-        if( widget )
-        { widget->removeEventFilter( this ); }
+        if (widget) {
+            widget->removeEventFilter(this);
+        }
     }
 
     //_____________________________________________________________
@@ -318,33 +325,35 @@ namespace QtCurve {
     {
 
         // check widget
-        if( !widget ) return false;
-
+        if (!widget) {
+            return false;
+        }
         // accepted default types
-        if(
-            ( qobject_cast<QDialog*>( widget ) && widget->isWindow() ) ||
-            ( qobject_cast<QMainWindow*>( widget ) && widget->isWindow() ) ||
-            qobject_cast<QGroupBox*>( widget ) )
-        { return true; }
-
+        if ((qobject_cast<QDialog*>(widget) && widget->isWindow()) ||
+            (qobject_cast<QMainWindow*>(widget) && widget->isWindow()) ||
+            qobject_cast<QGroupBox*>(widget)) {
+            return true;
+        }
         // more accepted types, provided they are not dock widget titles
-        if( ( qobject_cast<QMenuBar*>( widget ) ||
-            qobject_cast<QTabBar*>( widget ) ||
-            qobject_cast<QStatusBar*>( widget ) ||
-            qobject_cast<QToolBar*>( widget ) ) &&
-            !isDockWidgetTitle( widget ) )
-        { return true; }
-
-        if( widget->inherits( "KScreenSaver" ) && widget->inherits( "KCModule" ) )
-        { return true; }
-
-        if( isWhiteListed( widget ) )
-        { return true; }
-
+        if ((qobject_cast<QMenuBar*>(widget) ||
+             qobject_cast<QTabBar*>(widget) ||
+             qobject_cast<QStatusBar*>(widget) ||
+             qobject_cast<QToolBar*>(widget)) &&
+            !isDockWidgetTitle(widget)) {
+            return true;
+        }
+        if (widget->inherits("KScreenSaver") && widget->inherits("KCModule")) {
+            return true;
+        }
+        if (isWhiteListed(widget)) {
+            return true;
+        }
         // flat toolbuttons
-        if( QToolButton* toolButton = qobject_cast<QToolButton*>( widget ) )
-        { if( toolButton->autoRaise() ) return true; }
-
+        if (QToolButton *toolButton = qobject_cast<QToolButton*>(widget)) {
+            if (toolButton->autoRaise()) {
+                return true;
+            }
+        }
         // viewports
         /*
         one needs to check that
@@ -352,11 +361,19 @@ namespace QtCurve {
         2/ it matches its parent viewport
         3/ the parent is not blacklisted
         */
-        if( QListView* listView = qobject_cast<QListView*>( widget->parentWidget() ) )
-        { if( listView->viewport() == widget && !isBlackListed( listView ) ) return true; }
+        if (QListView *listView =
+            qobject_cast<QListView*>(widget->parentWidget())) {
+            if (listView->viewport() == widget && !isBlackListed(listView)) {
+                return true;
+            }
+        }
 
-        if( QTreeView* treeView = qobject_cast<QTreeView*>( widget->parentWidget() ) )
-        { if( treeView->viewport() == widget && !isBlackListed( treeView ) ) return true; }
+        if (QTreeView *treeView =
+            qobject_cast<QTreeView*>(widget->parentWidget())) {
+            if (treeView->viewport() == widget && !isBlackListed(treeView)) {
+                return true;
+            }
+        }
 
         //if( QGraphicsView* graphicsView = qobject_cast<QGraphicsView*>( widget->parentWidget() ) )
         //{ if( graphicsView->viewport() == widget && !isBlackListed( graphicsView ) ) return true; }
@@ -366,20 +383,18 @@ namespace QtCurve {
         this is because of kstatusbar
         who captures buttonPress/release events
         */
-        if( QLabel* label = qobject_cast<QLabel*>( widget ) )
-        {
-            if( label->textInteractionFlags().testFlag( Qt::TextSelectableByMouse ) ) return false;
-
-            QWidget* parent = label->parentWidget();
-            while( parent )
-            {
-                if( qobject_cast<QStatusBar*>( parent ) ) return true;
+        if (QLabel *label = qobject_cast<QLabel*>(widget)) {
+            if (label->textInteractionFlags()
+                .testFlag(Qt::TextSelectableByMouse))
+                return false;
+            QWidget *parent = label->parentWidget();
+            while (parent) {
+                if (qobject_cast<QStatusBar*>(parent))
+                    return true;
                 parent = parent->parentWidget();
             }
         }
-
         return false;
-
     }
 
     //_____________________________________________________________
@@ -506,15 +521,15 @@ namespace QtCurve {
         /* following checks are relevant only for WD_FULL mode */
 
         // tabbar. Make sure no tab is under the cursor
-        if( QTabBar* tabBar = qobject_cast<QTabBar*>( widget ) )
-        { return tabBar->tabAt( position ) == -1; }
+        if (QTabBar *tabBar = qobject_cast<QTabBar*>(widget)) {
+            return tabBar->tabAt(position) == -1;
+        }
 
         /*
         check groupboxes
         prevent drag if unchecking grouboxes
         */
-        if( QGroupBox *groupBox = qobject_cast<QGroupBox*>( widget ) )
-        {
+        if (QGroupBox *groupBox = qobject_cast<QGroupBox*>(widget)) {
             // non checkable group boxes are always ok
             if( !groupBox->isCheckable() ) return true;
 
@@ -618,12 +633,8 @@ WindowManager::startDrag(QWidget *widget, const QPoint &position)
     }
     // ungrab pointer
     if (useWMMoveResize()) {
-#ifdef QTC_ENABLE_X11
         qtcX11MoveTrigger(widget->window()->internalWinId(),
                           position.x(), position.y());
-#else
-        QTC_UNUSED(position);
-#endif
     }
     if (!useWMMoveResize()) {
         if (!_cursorOverride) {
@@ -634,19 +645,18 @@ WindowManager::startDrag(QWidget *widget, const QPoint &position)
     _dragInProgress = true;
     return;
 }
-    //____________________________________________________________
-    bool WindowManager::isDockWidgetTitle( const QWidget* widget ) const
-    {
-
-        if( !widget ) return false;
-        if( const QDockWidget* dockWidget = qobject_cast<const QDockWidget*>( widget->parent() ) )
-        {
 
+bool
+WindowManager::isDockWidgetTitle(const QWidget *widget) const
+{
+    QTC_RET_IF_FAIL(widget, false);
+    if (const QDockWidget *dockWidget =
+        qobject_cast<const QDockWidget*>(widget->parent())) {
             return widget == dockWidget->titleBarWidget();
-
-        } else return false;
-
+    } else {
+        return false;
     }
+}
 
     //____________________________________________________________
     bool WindowManager::AppEventFilter::eventFilter( QObject* object, QEvent* event )
