@@ -1,22 +1,24 @@
- /*
-  QtCurve (C) Craig Drummond, 2003 - 2010 craig.p.drummond@gmail.com
-
-  ----
-
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public
-  License version 2 as published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; see the file COPYING.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
- */
+/*****************************************************************************
+ *   Copyright 2003 - 2010 Craig Drummond <craig.p.drummond@gmail.com>       *
+ *   Copyright 2013 - 2014 Yichao Yu <yyc1992@gmail.com>                     *
+ *                                                                           *
+ *   This program is free software; you can redistribute it and/or modify    *
+ *   it under the terms of the GNU Lesser General Public License as          *
+ *   published by the Free Software Foundation; either version 2.1 of the    *
+ *   License, or (at your option) version 3, or any later version accepted   *
+ *   by the membership of KDE e.V. (or its successor approved by the         *
+ *   membership of KDE e.V.), which shall act as a proxy defined in          *
+ *   Section 6 of version 3 of the license.                                  *
+ *                                                                           *
+ *   This program is distributed in the hope that it will be useful,         *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of          *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       *
+ *   Lesser General Public License for more details.                         *
+ *                                                                           *
+ *   You should have received a copy of the GNU Lesser General Public        *
+ *   License along with this library. If not,                                *
+ *   see <http://www.gnu.org/licenses/>.                                     *
+ *****************************************************************************/
 
 #include <qtcurve-utils/dirs.h>
 #include "common.h"
@@ -29,9 +31,9 @@
 #include <QSvgRenderer>
 #include <QPainter>
 
-#define CONFIG_FILE               "stylerc"
-#define OLD_CONFIG_FILE           "qtcurvestylerc"
-#define VERSION_KEY               "version"
+#define CONFIG_FILE "stylerc"
+#define OLD_CONFIG_FILE "qtcurvestylerc"
+#define VERSION_KEY "version"
 
 #define TO_LATIN1(A) A.toLatin1().constData()
 static QString
@@ -44,16 +46,15 @@ determineFileName(const QString &file)
 
 static int c2h(char ch)
 {
-    return (ch>='0' && ch<='9') ? ch-'0' :
-           (ch>='a' && ch<='f') ? 10+(ch-'a') :
-           (ch>='A' && ch<='F') ? 10+(ch-'A') :
-           0;
+    return ((ch >= '0' && ch <= '9') ? ch - '0' :
+            (ch >= 'a' && ch <= 'f') ? 10 + (ch - 'a') :
+            (ch >= 'A' && ch <= 'F') ? 10 + (ch - 'A') : 0);
 }
 
-#define ATOH(str) ((c2h(*str)<<4)+c2h(*(str+1)))
+#define ATOH(str) ((c2h(*str) << 4) + c2h(*(str + 1)))
 
 void
-qtcSetRgb(color *col, const char *str)
+qtcSetRgb(QColor *col, const char *str)
 {
     if (str && strlen(str) > 6) {
         int offset = '#' == str[0] ? 1 : 0;
@@ -69,14 +70,14 @@ loadImage(const QString &file, QtCPixmap *pixmap)
 {
     // Need to store filename for config dialog!
     QString f(determineFileName(file));
-    pixmap->file=f;
+    pixmap->file = f;
     return pixmap->img.load(f);
 }
 
-static EDefBtnIndicator toInd(const char *str, EDefBtnIndicator def)
+static EDefBtnIndicator
+toInd(const char *str, EDefBtnIndicator def)
 {
-    if(str && 0!=str[0])
-    {
+    if (str && str[0]) {
         if(0==memcmp(str, "fontcolor", 9) || 0==memcmp(str, "border", 6))
             return IND_FONT_COLOR;
         if(0==memcmp(str, "none", 4))
@@ -94,14 +95,13 @@ static EDefBtnIndicator toInd(const char *str, EDefBtnIndicator def)
         if(0==memcmp(str, "origselected", 12))
             return IND_SELECTED;
     }
-
     return def;
 }
 
-static ELine toLine(const char *str, ELine def)
+static ELine
+toLine(const char *str, ELine def)
 {
-    if(str && 0!=str[0])
-    {
+    if (str && str[0]) {
         if(0==memcmp(str, "dashes", 6))
             return LINE_DASHES;
         if(0==memcmp(str, "none", 4))
@@ -118,10 +118,10 @@ static ELine toLine(const char *str, ELine def)
     return def;
 }
 
-static ETBarBorder toTBarBorder(const char *str, ETBarBorder def)
+static ETBarBorder
+toTBarBorder(const char *str, ETBarBorder def)
 {
-    if(str && 0!=str[0])
-    {
+    if (str && str[0]) {
         if(0==memcmp(str, "dark", 4))
             return 0==memcmp(&str[4], "-all", 4) ? TB_DARK_ALL : TB_DARK;
         if(0==memcmp(str, "none", 4))
@@ -132,10 +132,10 @@ static ETBarBorder toTBarBorder(const char *str, ETBarBorder def)
     return def;
 }
 
-static EMouseOver toMouseOver(const char *str, EMouseOver def)
+static EMouseOver
+toMouseOver(const char *str, EMouseOver def)
 {
-    if(str && 0!=str[0])
-    {
+    if (str && str[0]) {
         if(0==memcmp(str, "true", 4) || 0==memcmp(str, "colored", 7))
             return MO_COLORED;
         if(0==memcmp(str, "thickcolored", 12))
@@ -150,10 +150,11 @@ static EMouseOver toMouseOver(const char *str, EMouseOver def)
     return def;
 }
 
-static EAppearance toAppearance(const char *str, EAppearance def, EAppAllow allow, QtCPixmap *pix, bool checkImage)
+static EAppearance
+toAppearance(const char *str, EAppearance def, EAppAllow allow,
+             QtCPixmap *pix, bool checkImage)
 {
-    if(str && 0!=str[0])
-    {
+    if (str && str[0]) {
         if(0==memcmp(str, "flat", 4))
             return APPEARANCE_FLAT;
         if(0==memcmp(str, "raised", 6))
@@ -199,10 +200,11 @@ static EAppearance toAppearance(const char *str, EAppearance def, EAppAllow allo
     return def;
 }
 
-static EShade toShade(const char *str, bool allowMenu, EShade def, bool menuShade, color *col)
+static EShade
+toShade(const char *str, bool allowMenu, EShade def,
+        bool menuShade, QColor *col)
 {
-    if(str && 0!=str[0])
-    {
+    if (str && str[0]) {
         /* true/false is from 0.25... */
         if((!menuShade && 0==memcmp(str, "true", 4)) || 0==memcmp(str, "selected", 8))
             return SHADE_BLEND_SELECTED;
@@ -227,10 +229,10 @@ static EShade toShade(const char *str, bool allowMenu, EShade def, bool menuShad
 }
 
 /* Prior to 0.42 round was a bool - so need to read 'false' as 'none' */
-static ERound toRound(const char *str, ERound def)
+static ERound
+toRound(const char *str, ERound def)
 {
-    if(str && 0!=str[0])
-    {
+    if (str && str[0]) {
         if(0==memcmp(str, "none", 4) || 0==memcmp(str, "false", 5))
             return ROUND_NONE;
         if(0==memcmp(str, "slight", 6))
@@ -242,14 +244,13 @@ static ERound toRound(const char *str, ERound def)
         if(0==memcmp(str, "max", 3))
             return ROUND_MAX;
     }
-
     return def;
 }
 
-static EScrollbar toScrollbar(const char *str, EScrollbar def)
+static EScrollbar
+toScrollbar(const char *str, EScrollbar def)
 {
-    if(str && 0!=str[0])
-    {
+    if (str && str[0]) {
         if(0==memcmp(str, "kde", 3))
             return SCROLLBAR_KDE;
         if(0==memcmp(str, "windows", 7))
@@ -265,10 +266,10 @@ static EScrollbar toScrollbar(const char *str, EScrollbar def)
     return def;
 }
 
-static EFrame toFrame(const char *str, EFrame def)
+static EFrame
+toFrame(const char *str, EFrame def)
 {
-    if(str && 0!=str[0])
-    {
+    if (str && str[0]) {
         if(0==memcmp(str, "none", 4))
             return FRAME_NONE;
         if(0==memcmp(str, "plain", 5))
@@ -284,10 +285,10 @@ static EFrame toFrame(const char *str, EFrame def)
     return def;
 }
 
-static EEffect toEffect(const char *str, EEffect def)
+static EEffect
+toEffect(const char *str, EEffect def)
 {
-    if(str && 0!=str[0])
-    {
+    if (str && str[0]) {
         if(0==memcmp(str, "none", 4))
             return EFFECT_NONE;
         if(0==memcmp(str, "shadow", 6))
@@ -299,10 +300,10 @@ static EEffect toEffect(const char *str, EEffect def)
     return def;
 }
 
-static EShading toShading(const char *str, EShading def)
+static EShading
+toShading(const char *str, EShading def)
 {
-    if(str && 0!=str[0])
-    {
+    if (str && str[0]) {
         if(0==memcmp(str, "simple", 6))
             return SHADING_SIMPLE;
         if(0==memcmp(str, "hsl", 3))
@@ -316,10 +317,10 @@ static EShading toShading(const char *str, EShading def)
     return def;
 }
 
-static EStripe toStripe(const char *str, EStripe def)
+static EStripe
+toStripe(const char *str, EStripe def)
 {
-    if(str && 0!=str[0])
-    {
+    if (str && str[0]) {
         if(0==memcmp(str, "plain", 5) || 0==memcmp(str, "true", 4))
             return STRIPE_PLAIN;
         if(0==memcmp(str, "none", 4) || 0==memcmp(str, "false", 5))
@@ -437,9 +438,8 @@ static bool toLvLines(const char *str, bool def)
 
 static EGradientBorder toGradientBorder(const char *str, bool *haveAlpha)
 {
-    if(str && 0!=str[0])
-    {
-        *haveAlpha=strstr(str, "-alpha") ? true : false;
+    if (str && str[0]) {
+        *haveAlpha = strstr(str, "-alpha") ? true : false;
         if(0==memcmp(str, "light", 5) || 0==memcmp(str, "true", 4))
             return GB_LIGHT;
         if(0==memcmp(str, "none", 4))
@@ -606,7 +606,8 @@ void qtcLoadBgndImage(QtCImage *img)
 
 #endif
 
-static void checkColor(EShade *s, color *c)
+static void
+checkColor(EShade *s, QColor *c)
 {
     if(SHADE_CUSTOM==*s && IS_BLACK(*c))
         *s=SHADE_NONE;
@@ -698,13 +699,13 @@ static void readDoubleList(QtCConfig &cfg, const char *key, double *list, int co
 #define CFG_READ_COLOR(ENTRY) do {                      \
         QString sVal(cfg.readEntry(#ENTRY));            \
         if (sVal.isEmpty()) {                           \
-            opts->ENTRY=def->ENTRY;                     \
+            opts->ENTRY = def->ENTRY;                   \
         } else {                                        \
-            qtcSetRgb(&(opts->ENTRY), TO_LATIN1(sVal)); \
+            qtcSetRgb(&opts->ENTRY, TO_LATIN1(sVal));   \
         }                                               \
     } while (0)
 
-#define CFG_READ_IMAGE(ENTRY) do { \
+#define CFG_READ_IMAGE(ENTRY) do {                                      \
         opts->ENTRY.type =                                              \
             toImageType(TO_LATIN1(readStringEntry(cfg, #ENTRY)),        \
                         def->ENTRY.type);                               \
@@ -712,7 +713,7 @@ static void readDoubleList(QtCConfig &cfg, const char *key, double *list, int co
         opts->ENTRY.width = opts->ENTRY.height = 0;                     \
         opts->ENTRY.onBorder = false;                                   \
         opts->ENTRY.pos = PP_TR;                                        \
-        if (IMG_FILE == opts->ENTRY.type) {                             \
+        if (opts->ENTRY.type == IMG_FILE) {                             \
             QString file(cfg.readEntry(#ENTRY ".file"));                \
             if (!file.isEmpty()) {                                      \
                 opts->ENTRY.pixmap.file = file;                         \
@@ -723,7 +724,7 @@ static void readDoubleList(QtCConfig &cfg, const char *key, double *list, int co
                 opts->ENTRY.pos = (EPixPos)readNumEntry(cfg, #ENTRY ".pos", \
                                                         (int)PP_TR);    \
             } else {                                                    \
-                opts->ENTRY.type=IMG_NONE;                              \
+                opts->ENTRY.type = IMG_NONE;                            \
             }                                                           \
         }                                                               \
     } while (0)
@@ -1212,20 +1213,16 @@ bool qtcReadConfig(const QString &file, Options *opts, Options *defOpts, bool ch
                 CFG_READ_EFFECT(tbarBtnEffect);
             }
             CFG_READ_APPEARANCE_PIXMAP(bgndAppearance, APP_ALLOW_STRIPED,
-                                       &(opts->bgndPixmap), checkImages);
+                                       &opts->bgndPixmap, checkImages);
             CFG_READ_GRAD_TYPE(bgndGrad);
             CFG_READ_GRAD_TYPE(menuBgndGrad);
             CFG_READ_INT_BOOL(lighterPopupMenuBgnd, def->lighterPopupMenuBgnd);
             CFG_READ_APPEARANCE_PIXMAP(menuBgndAppearance, APP_ALLOW_STRIPED,
-                                       &(opts->menuBgndPixmap), checkImages);
+                                       &opts->menuBgndPixmap, checkImages);
 
             if(APPEARANCE_FLAT==opts->menuBgndAppearance && 0==opts->lighterPopupMenuBgnd && opts->version<qtcMakeVersion(1, 7))
                 opts->menuBgndAppearance=APPEARANCE_RAISED;
 
-#ifdef QTC_QT5_ENABLE_PARENTLESS_DIALOG_FIX_SUPPORT
-            CFG_READ_BOOL(fixParentlessDialogs);
-            CFG_READ_STRING_LIST(noDlgFixApps);
-#endif
             CFG_READ_STRIPE(stripedProgress);
             CFG_READ_SLIDER(sliderStyle);
             CFG_READ_BOOL(animatedProgress);
@@ -1390,8 +1387,8 @@ bool qtcReadConfig(const QString &file, Options *opts, Options *defOpts, bool ch
                 if (cols.count() &&
                     0 == (cols.count() % NUM_TITLEBAR_BUTTONS) &&
                     cols.count() <= (NUM_TITLEBAR_BUTTONS * 3)) {
-                    QStringList::ConstIterator it(cols.begin()),
-                                               end(cols.end());
+                    QStringList::ConstIterator it(cols.begin());
+                    QStringList::ConstIterator end(cols.end());
 
                     for (int i = 0;it != end;++it, ++i) {
                         QColor col;
@@ -1485,18 +1482,20 @@ void qtcDefaultSettings(Options *opts)
 {
     /* Set hard-coded defaults... */
     // Setup titlebar gradients...
-    qtcSetupGradient(&(opts->customGradient[APPEARANCE_CUSTOM1]), GB_3D,3,0.0,1.2,0.5,1.0,1.0,1.0);
-    qtcSetupGradient(&(opts->customGradient[APPEARANCE_CUSTOM2]), GB_3D,3,0.0,0.9,0.5,1.0,1.0,1.0);
-    opts->customShades[0]=1.16;
-    opts->customShades[1]=1.07;
-    opts->customShades[2]=0.9;
-    opts->customShades[3]=0.78;
-    opts->customShades[4]=0.84;
-    opts->customShades[5]=0.75;
-    opts->customAlphas[0]=0;
-    opts->contrast=7;
-    opts->passwordChar=0x25CF;
-    opts->gbFactor=DEF_GB_FACTOR;
+    qtcSetupGradient(&opts->customGradient[APPEARANCE_CUSTOM1], GB_3D, 3,
+                     0.0, 1.2, 0.5, 1.0, 1.0, 1.0);
+    qtcSetupGradient(&opts->customGradient[APPEARANCE_CUSTOM2], GB_3D, 3,
+                     0.0, 0.9, 0.5, 1.0, 1.0, 1.0);
+    opts->customShades[0] = 1.16;
+    opts->customShades[1] = 1.07;
+    opts->customShades[2] = 0.9;
+    opts->customShades[3] = 0.78;
+    opts->customShades[4] = 0.84;
+    opts->customShades[5] = 0.75;
+    opts->customAlphas[0] = 0;
+    opts->contrast = 7;
+    opts->passwordChar = 0x25CF;
+    opts->gbFactor = DEF_GB_FACTOR;
     opts->highlightFactor=DEFAULT_HIGHLIGHT_FACTOR;
     opts->crHighlight=DEFAULT_CR_HIGHLIGHT_FACTOR;
     opts->splitterHighlight=DEFAULT_SPLITTER_HIGHLIGHT_FACTOR;
@@ -1562,10 +1561,6 @@ void qtcDefaultSettings(Options *opts)
     opts->toolbarBorders=TB_NONE;
     opts->toolbarSeparators=LINE_SUNKEN;
     opts->splitters=LINE_1DOT;
-#ifdef QTC_QT5_ENABLE_PARENTLESS_DIALOG_FIX_SUPPORT
-    opts->fixParentlessDialogs=false;
-    opts->noDlgFixApps << "kate" << "plasma" << "plasma-desktop" << "plasma-netbook";
-#endif
     opts->customMenuTextColor=false;
     opts->coloredMouseOver=MO_GLOW;
     opts->menubarMouseOver=true;
@@ -1647,11 +1642,12 @@ void qtcDefaultSettings(Options *opts)
     opts->titlebarEffect=EFFECT_SHADOW;
     opts->centerTabText=false;
     opts->dwtSettings=DWT_BUTTONS_AS_PER_TITLEBAR|DWT_ROUND_TOP_ONLY;
-    opts->menubarApps << "amarok" << "arora" << "kaffeine" << "kcalc" << "smplayer" << "VirtualBox";
+    opts->menubarApps << "smplayer" << "VirtualBox";
     opts->statusbarApps << "kde";
-    opts->useQtFileDialogApps << "googleearth-bin";
-    opts->noMenuBgndOpacityApps << "inkscape" << "sonata" << "totem" << "vmware" << "vmplayer" << "gtk";
-    opts->noBgndOpacityApps << "smplayer" << "kaffeine" << "dragon" << "kscreenlocker" << "inkscape" << "sonata" << "totem" << "vmware" << "vmplayer";
+    opts->noMenuBgndOpacityApps << "sonata" << "totem" << "vmware"
+                                << "vmplayer" << "gtk";
+    opts->noBgndOpacityApps << "smplayer" << "sonata" << "totem" << "vmware"
+                            << "vmplayer";
     opts->noMenuStripeApps << "gtk" << "soffice.bin";
 
 #if defined CONFIG_DIALOG
@@ -1677,26 +1673,26 @@ void qtcDefaultSettings(Options *opts)
 #include <KDE/KConfig>
 #include <KDE/KConfigGroup>
 
-static const char *toStr(EDefBtnIndicator ind)
+static const char*
+toStr(EDefBtnIndicator ind)
 {
-    switch(ind)
-    {
-        case IND_NONE:
-            return "none";
-        case IND_FONT_COLOR:
-            return "fontcolor";
-        case IND_CORNER:
-            return "corner";
-        case IND_TINT:
-            return "tint";
-        case IND_GLOW:
-            return "glow";
-        case IND_DARKEN:
-            return "darken";
-        case IND_SELECTED:
-            return "origselected";
-        default:
-            return "colored";
+    switch (ind) {
+    case IND_NONE:
+        return "none";
+    case IND_FONT_COLOR:
+        return "fontcolor";
+    case IND_CORNER:
+        return "corner";
+    case IND_TINT:
+        return "tint";
+    case IND_GLOW:
+        return "glow";
+    case IND_DARKEN:
+        return "darken";
+    case IND_SELECTED:
+        return "origselected";
+    default:
+        return "colored";
     }
 }
 
@@ -2237,10 +2233,6 @@ bool qtcWriteConfig(KConfig *cfg, const Options &opts, const Options &def, bool
         CFG_WRITE_ENTRY(bgndGrad)
         CFG_WRITE_ENTRY(menuBgndGrad)
         CFG_WRITE_APPEARANCE_ENTRY_PIXMAP(menuBgndAppearance, APP_ALLOW_STRIPED, menuBgndPixmap)
-#ifdef QTC_QT5_ENABLE_PARENTLESS_DIALOG_FIX_SUPPORT
-        CFG_WRITE_ENTRY(fixParentlessDialogs)
-        CFG_WRITE_STRING_LIST_ENTRY(noDlgFixApps)
-#endif
         CFG_WRITE_ENTRY(stripedProgress)
         CFG_WRITE_ENTRY(sliderStyle)
         CFG_WRITE_ENTRY(animatedProgress)
