@@ -1,26 +1,28 @@
+/*****************************************************************************
+ *   Copyright 2007 - 2010 Craig Drummond <craig.p.drummond@gmail.com>       *
+ *   Copyright 2013 - 2014 Yichao Yu <yyc1992@gmail.com>                     *
+ *                                                                           *
+ *   This program is free software; you can redistribute it and/or modify    *
+ *   it under the terms of the GNU Lesser General Public License as          *
+ *   published by the Free Software Foundation; either version 2.1 of the    *
+ *   License, or (at your option) version 3, or any later version accepted   *
+ *   by the membership of KDE e.V. (or its successor approved by the         *
+ *   membership of KDE e.V.), which shall act as a proxy defined in          *
+ *   Section 6 of version 3 of the license.                                  *
+ *                                                                           *
+ *   This program is distributed in the hope that it will be useful,         *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of          *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       *
+ *   Lesser General Public License for more details.                         *
+ *                                                                           *
+ *   You should have received a copy of the GNU Lesser General Public        *
+ *   License along with this library. If not,                                *
+ *   see <http://www.gnu.org/licenses/>.                                     *
+ *****************************************************************************/
+
 #ifndef __QTCURVE_H__
 #define __QTCURVE_H__
 
-/*
-  QtCurve (C) Craig Drummond, 2007 - 2010 craig.p.drummond@gmail.com
-
-  ----
-
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public
-  License version 2 as published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; see the file COPYING.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
-*/
-
 #include <QTime>
 #include <QPalette>
 #include <QMap>
@@ -30,6 +32,7 @@
 #include <QColor>
 #include <QStyleOption>
 #include <QtGlobal>
+#include <QCommonStyle>
 typedef qulonglong QtcKey;
 #include <common/common.h>
 
@@ -37,14 +40,6 @@ typedef qulonglong QtcKey;
 #include <KDE/KComponentData>
 #endif
 
-// #ifdef QTC_KSTYLE
-// #include <kstyle.h>
-// #define BASE_STYLE KStyle
-// #else
-#include <QCommonStyle>
-#define BASE_STYLE QCommonStyle
-// #endif
-
 class QStyleOptionSlider;
 class QLabel;
 class QMenuBar;
@@ -60,14 +55,11 @@ namespace QtCurve {
 class WindowManager;
 class BlurHelper;
 class ShortcutHandler;
-#ifdef QTC_ENABLE_X11
 class ShadowHelper;
-#endif
 
-class Style : public BASE_STYLE {
+class Style: public QCommonStyle {
     Q_OBJECT
     Q_CLASSINFO("X-KDE-CustomElements", "true")
-
 public:
     enum BackgroundType {
         BGND_WINDOW,
@@ -93,14 +85,14 @@ public:
         PREVIEW_WINDOW
     };
 
-    class PreviewOption : public QStyleOption {
+    class PreviewOption: public QStyleOption {
     public:
         Options opts;
     };
 
-    class BgndOption : public QStyleOption {
+    class BgndOption: public QStyleOption {
     public:
-        EAppearance  app;
+        EAppearance app;
         QPainterPath path;
         QRect widgetRect;
     };
@@ -121,20 +113,33 @@ public:
     Style();
     ~Style();
 
-    virtual void polish(QPalette &palette) override;
     virtual void polish(QApplication *app) override;
+    virtual void polish(QPalette &palette) override;
     virtual void polish(QWidget *widget) override;
     virtual void unpolish(QApplication *app) override;
     virtual void unpolish(QWidget *widget) override;
 
     virtual bool eventFilter(QObject *object, QEvent *event) override;
     virtual void timerEvent(QTimerEvent *event) override;
+
     virtual int pixelMetric(PixelMetric metric, const QStyleOption *option=0,
                             const QWidget *widget=0) const override;
     virtual int styleHint(StyleHint hint, const QStyleOption *option,
                           const QWidget *widget,
                           QStyleHintReturn *returnData=0) const override;
+    virtual QSize sizeFromContents(ContentsType type,
+                                   const QStyleOption *option,
+                                   const QSize &size,
+                                   const QWidget *widget) const override;
     virtual QPalette standardPalette() const override;
+    virtual QIcon standardIcon(StandardPixmap pix, const QStyleOption *option=0,
+                               const QWidget *widget=0) const override;
+    virtual int layoutSpacing(QSizePolicy::ControlType control1,
+                              QSizePolicy::ControlType control2,
+                              Qt::Orientation orientation,
+                              const QStyleOption *option = 0,
+                              const QWidget *widget = 0) const override;
+
     virtual void drawPrimitive(PrimitiveElement element,
                                const QStyleOption *option,
                                QPainter *painter,
@@ -148,13 +153,9 @@ public:
                                     const QWidget *widget) const override;
     virtual void drawItemText(QPainter *painter, const QRect &rect, int flags,
                               const QPalette &pal, bool enabled,
-                              const QString &text,
-                              QPalette::ColorRole textRole =
+                              const QString &text, QPalette::ColorRole textRole=
                               QPalette::NoRole) const override;
-    virtual QSize sizeFromContents(ContentsType type,
-                                   const QStyleOption *option,
-                                   const QSize &size,
-                                   const QWidget *widget) const override;
+
     virtual QRect subElementRect(SubElement element, const QStyleOption *option,
                                  const QWidget *widget) const override;
     virtual QRect subControlRect(ComplexControl control,
@@ -166,9 +167,17 @@ public:
                                              const QPoint &pos,
                                              const QWidget *widget) const override;
 
-    Options &options() {
+    Options&
+    options()
+    {
         return opts;
     }
+    void prePolish(QWidget *w) const;
+    void
+    prePolish(const QWidget *w) const
+    {
+        prePolish(const_cast<QWidget*>(w));
+    }
 
 private:
     void init(bool initial);
@@ -202,28 +211,30 @@ private:
                            const QPainterPath &path, bool horiz, bool sel,
                            EAppearance bevApp, EWidget w=WIDGET_OTHER,
                            bool useCache=true) const;
-    void drawBevelGradientReal(const QColor &base, QPainter *p,
-                               const QRect &r, const QPainterPath &path,
-                               bool horiz, bool sel, EAppearance bevApp,
-                               EWidget w) const;
+    void drawBevelGradientReal(const QColor &base, QPainter *p, const QRect &r,
+                               const QPainterPath &path, bool horiz, bool sel,
+                               EAppearance bevApp, EWidget w) const;
 
-    void drawBevelGradient(const QColor &base, QPainter *p, QRect const &r,
-                           bool horiz, bool sel, EAppearance bevApp,
-                           EWidget w=WIDGET_OTHER, bool useCache=true) const {
+    void
+    drawBevelGradient(const QColor &base, QPainter *p, QRect const &r,
+                      bool horiz, bool sel, EAppearance bevApp,
+                      EWidget w=WIDGET_OTHER, bool useCache=true) const
+    {
         drawBevelGradient(base, p, r, QPainterPath(), horiz, sel, bevApp, w,
                           useCache);
     }
-    void drawBevelGradientReal(const QColor &base, QPainter *p, const QRect &r,
-                               bool horiz, bool sel, EAppearance bevApp,
-                               EWidget w) const {
+    void
+    drawBevelGradientReal(const QColor &base, QPainter *p, const QRect &r,
+                          bool horiz, bool sel,
+                          EAppearance bevApp, EWidget w) const
+    {
         drawBevelGradientReal(base, p, r, QPainterPath(), horiz,
                               sel, bevApp, w);
     }
 
     void drawSunkenBevel(QPainter *p, const QRect &r, const QColor &col) const;
-    void drawLightBevel(QPainter *p, const QRect &r,
-                        const QStyleOption *option, const QWidget *widget,
-                        int round, const QColor &fill,
+    void drawLightBevel(QPainter *p, const QRect &r, const QStyleOption *option,
+                        const QWidget *widget, int round, const QColor &fill,
                         const QColor *custom=0, bool doBorder=true,
                         EWidget w=WIDGET_OTHER) const;
     void drawLightBevelReal(QPainter *p, const QRect &r,
@@ -252,9 +263,9 @@ private:
     void buildSplitPath(const QRect &r, int round, double radius,
                         QPainterPath &tl, QPainterPath &br) const;
     void drawBorder(QPainter *p, const QRect &r, const QStyleOption *option,
-                    int round, const QColor *custom=0,
-                    EWidget w=WIDGET_OTHER, EBorder borderProfile=BORDER_FLAT,
-                    bool doBlend=true, int borderVal=QTC_STD_BORDER) const;
+                    int round, const QColor *custom=0, EWidget w=WIDGET_OTHER,
+                    EBorder borderProfile=BORDER_FLAT, bool doBlend=true,
+                    int borderVal=QTC_STD_BORDER) const;
     void drawMdiControl(QPainter *p, const QStyleOptionTitleBar *titleBar,
                         SubControl sc, const QWidget *widget,
                         ETitleBarButtons btn, const QColor &iconColor,
@@ -288,7 +299,6 @@ private:
     void drawSliderGroove(QPainter *p, const QRect &groove, const QRect &handle,
                           const QStyleOptionSlider *slider,
                           const QWidget *widget) const;
-    int  getOpacity(const QWidget *widget, QPainter *p) const;
     void drawMenuOrToolBarBackground(const QWidget *widget, QPainter *p,
                                      const QRect &r, const QStyleOption *option,
                                      bool menu=true, bool horiz=true) const;
@@ -301,25 +311,27 @@ private:
     void colorTab(QPainter *p, const QRect &r, bool horiz,
                   EWidget tab, int round) const;
     void shadeColors(const QColor &base, QColor *vals) const;
-    const QColor * buttonColors(const QStyleOption *option) const;
-    QColor         titlebarIconColor(const QStyleOption *option) const;
-    const QColor * popupMenuCols(const QStyleOption *option=0L) const;
-    const QColor * checkRadioColors(const QStyleOption *option) const;
-    const QColor * sliderColors(const QStyleOption *option) const;
-    const QColor * backgroundColors(const QColor &col) const;
-    const QColor * backgroundColors(const QStyleOption *option) const {
+    const QColor *buttonColors(const QStyleOption *option) const;
+    QColor titlebarIconColor(const QStyleOption *option) const;
+    const QColor *popupMenuCols(const QStyleOption *option=0L) const;
+    const QColor *checkRadioColors(const QStyleOption *option) const;
+    const QColor *sliderColors(const QStyleOption *option) const;
+    const QColor *backgroundColors(const QColor &col) const;
+    const QColor*
+    backgroundColors(const QStyleOption *option) const
+    {
         return (option ?
                 backgroundColors(option->palette.background().color()) :
-                itsBackgroundCols);
+                m_backgroundCols);
     }
-    const QColor * highlightColors(const QColor &col) const;
-    const QColor * highlightColors(const QStyleOption *option,
-                                   bool useActive) const {
-        return highlightColors(option->palette.brush(
-                                   useActive ?
-                                   QPalette::Active :
-                                   QPalette::Current,
-                                   QPalette::Highlight).color());
+    const QColor *highlightColors(const QColor &col) const;
+    const QColor*
+    highlightColors(const QStyleOption *option, bool useActive) const
+    {
+        return highlightColors(
+            option->palette.brush(useActive ? QPalette::Active :
+                                  QPalette::Current,
+                                  QPalette::Highlight).color());
     }
     const QColor *borderColors(const QStyleOption *option,
                                const QColor *use) const;
@@ -338,19 +350,11 @@ private:
     QPixmap *getPixmap(const QColor col, EPixmap p, double shade=1.0) const;
     const QColor &checkRadioCol(const QStyleOption *opt) const;
     QColor shade(const QColor &a, double k) const;
-    void shade(const color &ca, color *cb, double k) const;
+    void shade(const QColor &ca, QColor *cb, double k) const;
     QColor getLowerEtchCol(const QWidget *widget) const;
     int getFrameRound(const QWidget *widget) const;
-    void  unregisterArgbWidget(QWidget *w);
 
 private Q_SLOTS:
-    virtual QIcon standardIcon(StandardPixmap pix, const QStyleOption *option=0,
-                               const QWidget *widget=0) const override;
-    virtual int layoutSpacing(QSizePolicy::ControlType control1,
-                              QSizePolicy::ControlType control2,
-                              Qt::Orientation orientation,
-                              const QStyleOption *option = 0,
-                              const QWidget *widget = 0) const override;
     void kdeGlobalSettingsChange(int type, int);
     void borderSizesChanged();
     void toggleMenuBar(unsigned int xid);
@@ -367,70 +371,209 @@ private:
     void setDecorationColors();
     void applyKdeSettings(bool pal);
 #endif
-#ifdef QTC_ENABLE_X11
     bool isWindowDragWidget(QObject *o);
     void emitMenuSize(QWidget *w, unsigned short size, bool force=false);
     void emitStatusBarState(QStatusBar *sb);
-#endif
+    const QColor&
+    MOArrow(QFlags<State> state, const QPalette &palette, bool mo,
+            QPalette::ColorRole rol) const
+    {
+        if (!(state & State_Enabled)) {
+            return palette.color(QPalette::Disabled, rol);
+        } else if (opts.coloredMouseOver != MO_NONE && mo) {
+            return m_mouseOverCols[ARROW_MO_SHADE];
+        } else {
+            return palette.color(rol);
+        }
+    }
+    const QColor&
+    MOArrow(QFlags<State> state, const QPalette &palette,
+            QPalette::ColorRole rol) const
+    {
+        return MOArrow(state, palette, state & State_MouseOver, rol);
+    }
+
+    bool
+    drawPrimitiveNone(PrimitiveElement element,
+                      const QStyleOption *option,
+                      QPainter *painter,
+                      const QWidget *widget) const
+    {
+        QTC_UNUSED(element);
+        QTC_UNUSED(option);
+        QTC_UNUSED(painter);
+        QTC_UNUSED(widget);
+        return true;
+    }
+    bool drawPrimitivePanelMenu(PrimitiveElement element,
+                                const QStyleOption *option,
+                                QPainter *painter,
+                                const QWidget *widget) const;
+    bool drawPrimitiveIndicatorTabClose(PrimitiveElement element,
+                                        const QStyleOption *option,
+                                        QPainter *painter,
+                                        const QWidget *widget) const;
+    bool drawPrimitiveWidget(PrimitiveElement element,
+                             const QStyleOption *option,
+                             QPainter *painter,
+                             const QWidget *widget) const;
+    bool drawPrimitivePanelScrollAreaCorner(PrimitiveElement element,
+                                            const QStyleOption *option,
+                                            QPainter *painter,
+                                            const QWidget *widget) const;
+    bool drawPrimitiveIndicatorBranch(PrimitiveElement element,
+                                      const QStyleOption *option,
+                                      QPainter *painter,
+                                      const QWidget *widget) const;
+    bool drawPrimitiveIndicatorViewItemCheck(PrimitiveElement element,
+                                             const QStyleOption *option,
+                                             QPainter *painter,
+                                             const QWidget *widget) const;
+    bool drawPrimitiveIndicatorHeaderArrow(PrimitiveElement element,
+                                           const QStyleOption *option,
+                                           QPainter *painter,
+                                           const QWidget *widget) const;
+    bool drawPrimitiveIndicatorArrow(PrimitiveElement element,
+                                     const QStyleOption *option,
+                                     QPainter *painter,
+                                     const QWidget *widget) const;
+    bool drawPrimitiveIndicatorSpin(PrimitiveElement element,
+                                    const QStyleOption *option,
+                                    QPainter *painter,
+                                    const QWidget *widget) const;
+    bool drawPrimitiveIndicatorToolBarSeparator(PrimitiveElement element,
+                                                const QStyleOption *option,
+                                                QPainter *painter,
+                                                const QWidget *widget) const;
+    bool drawPrimitiveFrameGroupBox(PrimitiveElement element,
+                                    const QStyleOption *option,
+                                    QPainter *painter,
+                                    const QWidget *widget) const;
+    bool drawPrimitiveFrame(PrimitiveElement element,
+                            const QStyleOption *option, QPainter *painter,
+                            const QWidget *widget) const;
+    bool drawPrimitivePanelMenuBar(PrimitiveElement element,
+                                   const QStyleOption *option,
+                                   QPainter *painter,
+                                   const QWidget *widget) const;
+    bool drawPrimitivePanelTipLabel(PrimitiveElement element,
+                                    const QStyleOption *option,
+                                    QPainter *painter,
+                                    const QWidget *widget) const;
+    bool drawPrimitiveQtcBackground(PrimitiveElement element,
+                                    const QStyleOption *option,
+                                    QPainter *painter,
+                                    const QWidget *widget) const;
+    bool drawPrimitivePanelItemViewItem(PrimitiveElement element,
+                                        const QStyleOption *option,
+                                        QPainter *painter,
+                                        const QWidget *widget) const;
+    bool drawPrimitiveFrameTabWidget(PrimitiveElement element,
+                                     const QStyleOption *option,
+                                     QPainter *painter,
+                                     const QWidget *widget) const;
+    bool drawPrimitiveFrameWindow(PrimitiveElement element,
+                                  const QStyleOption *option,
+                                  QPainter *painter,
+                                  const QWidget *widget) const;
+    bool drawPrimitiveButton(PrimitiveElement element,
+                             const QStyleOption *option, QPainter *painter,
+                             const QWidget *widget) const;
+    bool drawPrimitiveFrameFocusRect(PrimitiveElement element,
+                                     const QStyleOption *option,
+                                     QPainter *painter,
+                                     const QWidget *widget) const;
+    bool drawPrimitiveIndicatorToolBarHandle(PrimitiveElement element,
+                                             const QStyleOption *option,
+                                             QPainter *painter,
+                                             const QWidget *widget) const;
+    bool drawPrimitiveIndicatorRadioButton(PrimitiveElement element,
+                                           const QStyleOption *option,
+                                           QPainter *painter,
+                                           const QWidget *widget) const;
+    bool drawPrimitiveIndicatorCheckBox(PrimitiveElement element,
+                                        const QStyleOption *option,
+                                        QPainter *painter,
+                                        const QWidget *widget) const;
+    bool drawPrimitiveFrameLineEdit(PrimitiveElement element,
+                                    const QStyleOption *option,
+                                    QPainter *painter,
+                                    const QWidget *widget) const;
+    bool drawPrimitivePanelLineEdit(PrimitiveElement element,
+                                    const QStyleOption *option,
+                                    QPainter *painter,
+                                    const QWidget *widget) const;
+    bool drawPrimitiveIndicatorDockWidgetResizeHandle(
+        PrimitiveElement element, const QStyleOption *option,
+        QPainter *painter, const QWidget *widget) const;
+    bool drawPrimitiveButtonTool(PrimitiveElement element,
+                                 const QStyleOption *option, QPainter *painter,
+                                 const QWidget *widget) const;
+    bool drawPrimitiveFrameDockWidget(PrimitiveElement element,
+                                      const QStyleOption *option,
+                                      QPainter *painter,
+                                      const QWidget *widget) const;
+    bool drawPrimitiveFrameStatusBarOrMenu(PrimitiveElement element,
+                                           const QStyleOption *option,
+                                           QPainter *painter,
+                                           const QWidget *widget) const;
+    bool drawPrimitiveFrameTabBarBase(PrimitiveElement element,
+                                      const QStyleOption *option,
+                                      QPainter *painter,
+                                      const QWidget *widget) const;
 
 private:
     mutable Options opts;
-    QColor itsHighlightCols[TOTAL_SHADES+1],
-        itsBackgroundCols[TOTAL_SHADES+1],
-        itsMenubarCols[TOTAL_SHADES+1],
-        itsFocusCols[TOTAL_SHADES+1],
-        itsMouseOverCols[TOTAL_SHADES+1],
-        *itsPopupMenuCols,
-        *itsSliderCols,
-        *itsDefBtnCols,
-        *itsComboBtnCols,
-        *itsCheckRadioSelCols,
-        *itsSortedLvColors,
-        *itsOOMenuCols,
-        *itsProgressCols,
-        itsButtonCols[TOTAL_SHADES+1],
-        itsCheckRadioCol;
-    bool itsSaveMenuBarStatus,
-        itsSaveStatusBarStatus,
-        itsUsePixmapCache,
-        itsInactiveChangeSelectionColor;
-    PreviewType itsIsPreview;
-    mutable QColor *itsSidebarButtonsCols;
-    mutable QColor *itsActiveMdiColors;
-    mutable QColor *itsMdiColors;
-    mutable QColor itsActiveMdiTextColor;
-    mutable QColor itsMdiTextColor;
-    mutable QColor itsColoredButtonCols[TOTAL_SHADES+1];
-    mutable QColor itsColoredBackgroundCols[TOTAL_SHADES+1];
-    mutable QColor itsColoredHighlightCols[TOTAL_SHADES+1];
-    mutable QCache<QtcKey, QPixmap> itsPixmapCache;
-    mutable bool itsActive;
-    mutable const QWidget *itsSbWidget;
-    mutable QLabel *itsClickedLabel;
-    QSet<QProgressBar*> itsProgressBars;
-    QSet<QWidget*> itsTransparentWidgets;
-    int itsProgressBarAnimateTimer,
-        itsAnimateStep;
-    QTime itsTimer;
-    mutable QMap<int, QColor*> itsTitleBarButtonsCols;
-#ifdef QTC_QT5_ENABLE_PARENTLESS_DIALOG_FIX_SUPPORT
-    mutable QMap<QWidget*, QWidget*> itsReparentedDialogs;
-#endif
-    mutable QList<int> itsMdiButtons[2]; // 0=left, 1=right
-    mutable int itsTitlebarHeight;
+    QColor m_highlightCols[TOTAL_SHADES + 1],
+        m_backgroundCols[TOTAL_SHADES + 1],
+        m_menubarCols[TOTAL_SHADES + 1],
+        m_focusCols[TOTAL_SHADES + 1],
+        m_mouseOverCols[TOTAL_SHADES + 1],
+        *m_popupMenuCols,
+        *m_sliderCols,
+        *m_defBtnCols,
+        *m_comboBtnCols,
+        *m_checkRadioSelCols,
+        *m_sortedLvColors,
+        *m_ooMenuCols,
+        *m_progressCols,
+        m_buttonCols[TOTAL_SHADES + 1],
+        m_checkRadioCol;
+    bool m_saveMenuBarStatus,
+        m_saveStatusBarStatus,
+        m_usePixmapCache,
+        m_inactiveChangeSelectionColor;
+    PreviewType m_isPreview;
+    mutable QColor *m_sidebarButtonsCols;
+    mutable QColor *m_activeMdiColors;
+    mutable QColor *m_mdiColors;
+    mutable QColor m_activeMdiTextColor;
+    mutable QColor m_mdiTextColor;
+    mutable QColor m_coloredButtonCols[TOTAL_SHADES + 1];
+    mutable QColor m_coloredBackgroundCols[TOTAL_SHADES + 1];
+    mutable QColor m_coloredHighlightCols[TOTAL_SHADES + 1];
+    mutable QCache<QtcKey, QPixmap> m_pixmapCache;
+    mutable bool m_active;
+    mutable const QWidget *m_sbWidget;
+    mutable QLabel *m_clickedLabel;
+    QSet<QProgressBar*> m_progressBars;
+    int m_progressBarAnimateTimer,
+        m_animateStep;
+    QTime m_timer;
+    mutable QMap<int, QColor*> m_titleBarButtonsCols;
+    mutable QList<int> m_mdiButtons[2]; // 0=left, 1=right
+    mutable int m_titlebarHeight;
 
-#ifdef QTC_ENABLE_X11
-    QDBusInterface *itsDBus;
-    QtCurve::ShadowHelper *itsShadowHelper;
-#endif
-    mutable QScrollBar *itsSViewSBar;
-    mutable QMap<QWidget*, QSet<QWidget*> > itsSViewContainers;
+    QDBusInterface *m_dBus;
+    ShadowHelper *m_shadowHelper;
+    mutable QScrollBar *m_sViewSBar;
+    mutable QMap<QWidget*, QSet<QWidget*> > m_sViewContainers;
 #ifdef QTC_QT5_ENABLE_KDE
-    KComponentData itsComponentData;
+    KComponentData m_componentData;
 #endif
-    QtCurve::WindowManager *itsWindowManager;
-    QtCurve::BlurHelper *itsBlurHelper;
-    QtCurve::ShortcutHandler *itsShortcutHandler;
+    WindowManager *m_windowManager;
+    BlurHelper *m_blurHelper;
+    ShortcutHandler *m_shortcutHandler;
 };
 }
 
