@@ -1,9 +1,29 @@
-// krazy:excludeall=qclasses
+/*****************************************************************************
+ *   Copyright 2010 Craig Drummond <craig.p.drummond@gmail.com>              *
+ *   Copyright 2013 - 2014 Yichao Yu <yyc1992@gmail.com>                     *
+ *                                                                           *
+ *   This program is free software; you can redistribute it and/or modify    *
+ *   it under the terms of the GNU Lesser General Public License as          *
+ *   published by the Free Software Foundation; either version 2.1 of the    *
+ *   License, or (at your option) version 3, or any later version accepted   *
+ *   by the membership of KDE e.V. (or its successor approved by the         *
+ *   membership of KDE e.V.), which shall act as a proxy defined in          *
+ *   Section 6 of version 3 of the license.                                  *
+ *                                                                           *
+ *   This program is distributed in the hope that it will be useful,         *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of          *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       *
+ *   Lesser General Public License for more details.                         *
+ *                                                                           *
+ *   You should have received a copy of the GNU Lesser General Public        *
+ *   License along with this library. If not,                                *
+ *   see <http://www.gnu.org/licenses/>.                                     *
+ *****************************************************************************/
 
 // Copied from oxygenwindowmanager.cpp svnversion: 1139230
 
 //////////////////////////////////////////////////////////////////////////////
-// oxygenwindowmanager.cpp
+// windowmanager.cpp
 // pass some window mouse press/release/move event actions to window manager
 // -------------------
 //
@@ -65,20 +85,14 @@
 #  include <KGlobalSettings>
 #endif
 
-#ifdef QTC_ENABLE_X11
-#  include <qtcurve-utils/x11wmmove.h>
-#endif
+#include <qtcurve-utils/x11wmmove.h>
 
 namespace QtCurve {
 //_____________________________________________________________
 WindowManager::WindowManager( QObject* parent ):
     QObject( parent ),
     _enabled( true ),
-#ifdef QTC_ENABLE_X11
-    _useWMMoveResize(true),
-#else
-    _useWMMoveResize(false),
-#endif
+    _useWMMoveResize(qtcX11Enabled()),
     _dragMode( WM_DRAG_NONE ),
 #ifndef QTC_QT5_ENABLE_KDE
     _dragDistance( QApplication::startDragDistance() ),
@@ -92,8 +106,8 @@ WindowManager::WindowManager( QObject* parent ):
     _cursorOverride( false )
 {
     // install application wise event filter
-    _appEventFilter = new AppEventFilter( this );
-    qApp->installEventFilter( _appEventFilter );
+    _appEventFilter = new AppEventFilter(this);
+    qApp->installEventFilter(_appEventFilter);
 }
 
 //_____________________________________________________________
@@ -112,31 +126,28 @@ void WindowManager::initialize( int windowDrag, const QStringList &whiteList, co
     initializeBlackList(blackList);
 }
 
-//_____________________________________________________________
-void WindowManager::registerWidget( QWidget* widget )
+void
+WindowManager::registerWidget(QWidget *widget)
 {
 
-    if( isBlackListed( widget ) )
-    {
-
+    if (isBlackListed(widget)) {
         /*
           also install filter for blacklisted widgets
           to be able to catch the relevant events and prevent
           the drag to happen
         */
-        Utils::addEventFilter(widget, this);
-
-    } else if( isDragable( widget ) ) {
-        Utils::addEventFilter(widget, this);
+        widget->installEventFilter(this);
+    } else if (isDragable(widget)) {
+        widget->installEventFilter(this);
     }
-
 }
 
-//_____________________________________________________________
-void WindowManager::unregisterWidget( QWidget* widget )
+void
+WindowManager::unregisterWidget(QWidget *widget)
 {
-    if( widget )
-    { widget->removeEventFilter( this ); }
+    if (widget) {
+        widget->removeEventFilter(this);
+    }
 }
 
 //_____________________________________________________________
@@ -618,10 +629,8 @@ void WindowManager::startDrag(QWidget* widget, const QPoint &position)
 
     // ungrab pointer
     if (useWMMoveResize()) {
-#ifdef QTC_ENABLE_X11
         qtcX11MoveTrigger(widget->window()->internalWinId(),
                           position.x(), position.y());
-#endif
     }
 
     if(!useWMMoveResize()) {
